@@ -23,29 +23,27 @@ export function parseLabels(labels: string): Labels {
  * Returns a map labels that are common to the given label sets.
  */
 export function findCommonLabels(labelsSets: Labels[]): Labels {
-  return labelsSets.reduce((acc, labels) => {
-    if (!labels) {
-      throw new Error('Need parsed labels to find common labels.');
-    }
-    if (!acc) {
-      // Initial set
-      acc = { ...labels };
-    } else {
+  return labelsSets.reduce(
+    (acc, labels) => {
+      if (!labels) {
+        throw new Error('Need parsed labels to find common labels.');
+      }
       // Remove incoming labels that are missing or not matching in value
-      Object.keys(labels).forEach(key => {
+      Object.keys(labels).forEach((key) => {
         if (acc[key] === undefined || acc[key] !== labels[key]) {
           delete acc[key];
         }
       });
       // Remove common labels that are missing from incoming label set
-      Object.keys(acc).forEach(key => {
+      Object.keys(acc).forEach((key) => {
         if (labels[key] === undefined) {
           delete acc[key];
         }
       });
-    }
-    return acc;
-  }, (undefined as unknown) as Labels);
+      return acc;
+    },
+    { ...labelsSets[0] }
+  );
 }
 
 /**
@@ -53,7 +51,7 @@ export function findCommonLabels(labelsSets: Labels[]): Labels {
  */
 export function findUniqueLabels(labels: Labels | undefined, commonLabels: Labels): Labels {
   const uncommonLabels: Labels = { ...labels };
-  Object.keys(commonLabels).forEach(key => {
+  Object.keys(commonLabels).forEach((key) => {
     delete uncommonLabels[key];
   });
   return uncommonLabels;
@@ -82,7 +80,7 @@ export function formatLabels(labels: Labels, defaultValue = '', withoutBraces?:
     return defaultValue;
   }
   const labelKeys = Object.keys(labels).sort();
-  const cleanSelector = labelKeys.map(key => `${key}="${labels[key]}"`).join(', ');
+  const cleanSelector = labelKeys.map((key) => `${key}="${labels[key]}"`).join(', ');
   if (withoutBraces) {
     return cleanSelector;
   }
