@@ -1,4 +1,5 @@
-import React, { SyntheticEvent, useState } from 'react';
+// Core Grafana history https://github.com/grafana/grafana/blob/v11.0.0-preview/public/app/plugins/datasource/prometheus/configuration/PromSettings.tsx
+import { SyntheticEvent, useState } from 'react';
 
 import {
   DataSourcePluginOptionsEditorProps,
@@ -8,8 +9,10 @@ import {
 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
 import { ConfigSubSection } from '@grafana/experimental';
+import { config } from '@grafana/runtime';
 import { InlineField, Input, Select, Switch, useTheme2 } from '@grafana/ui';
 
+import { SUGGESTIONS_LIMIT } from '../language_provider';
 import { QueryEditorMode } from '../querybuilder/shared/types';
 import { defaultPrometheusQueryOverlapWindow } from '../querycache/QueryCache';
 import { PromApplication, PrometheusCacheLevel, PromOptions } from '../types';
@@ -52,7 +55,10 @@ export const DURATION_REGEX = /^$|^\d+(ms|[Mwdhmsy])$/;
 // multiple duration input
 export const MULTIPLE_DURATION_REGEX = /(\d+)(.+)/;
 
+export const NON_NEGATIVE_INTEGER_REGEX = /^(0|[1-9]\d*)(\.\d+)?(e\+?\d+)?$/; // non-negative integers, including scientific notation
+
 const durationError = 'Value is not valid, you can use number with time unit specifier: y, M, w, d, h, m, s';
+export const countError = 'Value is not valid, you can use non-negative integers, including scientific notation';
 
 export const PromSettings = (props: Props) => {
   const { options, onOptionsChange } = props;
@@ -78,6 +84,14 @@ export const PromSettings = (props: Props) => {
     incrementalQueryOverlapWindow: '',
   });
 
+  type ValidCount = {
+    codeModeMetricNamesSuggestionLimit: string;
+  };
+
+  const [validCount, updateValidCount] = useState<ValidCount>({
+    codeModeMetricNamesSuggestionLimit: '',
+  });
+
   return (
     <>
       <ConfigSubSection title="Interval behaviour" className={styles.container}>
@@ -301,6 +315,49 @@ export const PromSettings = (props: Props) => {
             </div>
           </div>
 
+          {config.featureToggles.prometheusCodeModeMetricNamesSearch && (
+            <div className="gf-form-inline">
+              <div className="gf-form">
+                <InlineField
+                  label="Metric names suggestion limit"
+                  labelWidth={PROM_CONFIG_LABEL_WIDTH}
+                  tooltip={
+                    <>
+                      The maximum number of metric names that may appear as autocomplete suggestions in the query
+                      editor&apos;s Code mode.
+                    </>
+                  }
+                  interactive={true}
+                  disabled={options.readOnly}
+                >
+                  <>
+                    <Input
+                      className="width-20"
+                      value={options.jsonData.codeModeMetricNamesSuggestionLimit}
+                      onChange={onChangeHandler('codeModeMetricNamesSuggestionLimit', options, onOptionsChange)}
+                      spellCheck={false}
+                      placeholder={SUGGESTIONS_LIMIT.toString()}
+                      onBlur={(e) =>
+                        updateValidCount({
+                          ...validCount,
+                          codeModeMetricNamesSuggestionLimit: e.currentTarget.value,
+                        })
+                      }
+                      data-testid={
+                        selectors.components.DataSource.Prometheus.configPage.codeModeMetricNamesSuggestionLimit
+                      }
+                    />
+                    {validateInput(
+                      validCount.codeModeMetricNamesSuggestionLimit,
+                      NON_NEGATIVE_INTEGER_REGEX,
+                      countError
+                    )}
+                  </>
+                </InlineField>
+              </div>
+            </div>
+          )}
+
           <div className="gf-form-inline">
             <div className="gf-form max-width-30">
               <InlineField
@@ -435,6 +492,26 @@ export const PromSettings = (props: Props) => {
               </InlineField>
             </div>
           </div>
+          <InlineField
+            labelWidth={PROM_CONFIG_LABEL_WIDTH}
+            label="Use series endpoint"
+            tooltip={
+              <>
+                Checking this option will favor the series endpoint with match[] parameter over the label values
+                endpoint with match[] parameter. While the label values endpoint is considered more performant, some
+                users may prefer the series because it has a POST method while the label values endpoint only has a GET
+                method. {docsTip()}
+              </>
+            }
+            interactive={true}
+            disabled={options.readOnly}
+            className={styles.switchField}
+          >
+            <Switch
+              value={options.jsonData.seriesEndpoint ?? false}
+              onChange={onUpdateDatasourceJsonDataOptionChecked(props, 'seriesEndpoint')}
+            />
+          </InlineField>
         </div>
       </ConfigSubSection>
 
