@@ -1,18 +1,20 @@
 import { Meta } from '@storybook/react';
-import React from 'react';
+import { useState } from 'react';
 
 import { useTheme2 } from '../../themes';
 
+import mdx from './ColorPicker.mdx';
 import { ColorPickerPopover } from './ColorPickerPopover';
 import { SeriesColorPickerPopover } from './SeriesColorPickerPopover';
 
 const meta: Meta<typeof ColorPickerPopover> = {
   title: 'Pickers and Editors/ColorPicker/Popovers',
   component: ColorPickerPopover,
-  // SB7 has broken subcomponent types due to dropping support for the feature
-  // https://github.com/storybookjs/storybook/issues/20782
-  // @ts-ignore
-  subcomponents: { SeriesColorPickerPopover },
+  parameters: {
+    docs: {
+      page: mdx,
+    },
+  },
 };
 
 export const Basic = () => {
@@ -30,11 +32,14 @@ export const Basic = () => {
 
 export const SeriesColorPickerPopoverExample = () => {
   const theme = useTheme2();
+  const [yAxis, setYAxis] = useState(0);
 
   return (
     <div style={{ position: 'absolute' }}>
       <SeriesColorPickerPopover
         theme={theme}
+        yaxis={yAxis}
+        onToggleAxis={() => (yAxis ? setYAxis(0) : setYAxis(2))}
         color="#BC67E6"
         onChange={(color: string) => {
           console.log(color);
