@@ -1,8 +1,7 @@
-import React from 'react';
-
 import { DataSourceJsonData, DataSourcePluginOptionsEditorProps } from '@grafana/data';
 
 import { InlineSwitch } from '../../components/Switch/Switch';
+import { Trans } from '../../utils/i18n';
 import { InlineField } from '../Forms/InlineField';
 
 export interface Props<T extends DataSourceJsonData>
@@ -18,7 +17,9 @@ export function SecureSocksProxySettings<T extends SecureSocksProxyConfig>({
 }: Props<T>): JSX.Element {
   return (
     <>
-      <h3 className="page-heading">Secure Socks Proxy</h3>
+      <h3 className="page-heading">
+        <Trans i18nKey="grafana-ui.data-source-settings.secure-socks-heading">Secure Socks Proxy</Trans>
+      </h3>
       <div className="gf-form-group">
         <div className="gf-form-inline">
           <div className="gf-form">
