@@ -1,10 +1,10 @@
 import { css } from '@emotion/css';
-import React from 'react';
+import { memo, forwardRef } from 'react';
 
 import { FeatureState, GrafanaTheme2 } from '@grafana/data';
 
 import { useStyles2 } from '../../themes';
-import { Badge, BadgeProps } from '../Badge/Badge';
+import { FeatureBadge } from '../FeatureBadge/FeatureBadge';
 
 import { InfoBox, InfoBoxProps } from './InfoBox';
 
@@ -14,8 +14,8 @@ export interface FeatureInfoBoxProps extends Omit<InfoBoxProps, 'title' | 'urlTi
 }
 
 /** @deprecated use Alert with severity info */
-export const FeatureInfoBox = React.memo(
-  React.forwardRef<HTMLDivElement, FeatureInfoBoxProps>(({ title, featureState, ...otherProps }, ref) => {
+export const FeatureInfoBox = memo(
+  forwardRef<HTMLDivElement, FeatureInfoBoxProps>(({ title, featureState, ...otherProps }, ref) => {
     const styles = useStyles2(getFeatureInfoBoxStyles);
 
     const titleEl = featureState ? (
@@ -41,30 +41,3 @@ const getFeatureInfoBoxStyles = (theme: GrafanaTheme2) => {
     }),
   };
 };
-
-interface FeatureBadgeProps {
-  featureState: FeatureState;
-  tooltip?: string;
-}
-
-export const FeatureBadge = ({ featureState, tooltip }: FeatureBadgeProps) => {
-  const display = getPanelStateBadgeDisplayModel(featureState);
-  return <Badge text={display.text} color={display.color} icon={display.icon} tooltip={tooltip} />;
-};
-
-function getPanelStateBadgeDisplayModel(featureState: FeatureState): BadgeProps {
-  switch (featureState) {
-    case FeatureState.alpha:
-      return {
-        text: 'Alpha',
-        icon: 'exclamation-triangle',
-        color: 'orange',
-      };
-  }
-
-  return {
-    text: 'Beta',
-    icon: 'rocket',
-    color: 'blue',
-  };
-}
