@@ -1,10 +1,12 @@
 import { css, cx } from '@emotion/css';
-import React, { useCallback, useMemo, useState } from 'react';
+import { useCallback, useMemo, useState } from 'react';
+import * as React from 'react';
 
 import { Field, GrafanaTheme2, SelectableValue } from '@grafana/data';
 
-import { Button, ClickOutsideWrapper, HorizontalGroup, IconButton, Label, VerticalGroup } from '..';
+import { Button, ClickOutsideWrapper, IconButton, Label, Stack } from '..';
 import { useStyles2, useTheme2 } from '../../themes';
+import { Trans } from '../../utils/i18n';
 
 import { FilterList } from './FilterList';
 import { TableStyles } from './styles';
@@ -65,10 +67,12 @@ export const FilterPopup = ({
       {/* This is just blocking click events from bubbeling and should not have a keyboard interaction. */}
       {/* eslint-disable-next-line jsx-a11y/no-static-element-interactions, jsx-a11y/click-events-have-key-events */}
       <div className={cx(styles.filterContainer)} onClick={stopPropagation}>
-        <VerticalGroup spacing="lg">
-          <VerticalGroup spacing="xs">
-            <HorizontalGroup justify="space-between" align="center">
-              <Label className={styles.label}>Filter by values:</Label>
+        <Stack direction="column" gap={3}>
+          <Stack direction="column" gap={0.5}>
+            <Stack justifyContent="space-between" alignItems="center">
+              <Label className={styles.label}>
+                <Trans i18nKey="grafana-ui.table.filter-popup-heading">Filter by values:</Trans>
+              </Label>
               <IconButton
                 name="text-fields"
                 tooltip="Match case"
@@ -77,7 +81,7 @@ export const FilterPopup = ({
                   setMatchCase((s) => !s);
                 }}
               />
-            </HorizontalGroup>
+            </Stack>
             <div className={cx(styles.listDivider)} />
             <FilterList
               onChange={setValues}
@@ -90,25 +94,25 @@ export const FilterPopup = ({
               operator={operator}
               setOperator={setOperator}
             />
-          </VerticalGroup>
-          <HorizontalGroup spacing="lg">
-            <HorizontalGroup>
+          </Stack>
+          <Stack gap={3}>
+            <Stack>
               <Button size="sm" onClick={onFilter}>
-                Ok
+                <Trans i18nKey="grafana-ui.table.filter-popup-apply">Ok</Trans>
               </Button>
               <Button size="sm" variant="secondary" onClick={onCancel}>
-                Cancel
+                <Trans i18nKey="grafana-ui.table.filter-popup-cancel">Cancel</Trans>
               </Button>
-            </HorizontalGroup>
+            </Stack>
             {clearFilterVisible && (
-              <HorizontalGroup>
+              <Stack>
                 <Button fill="text" size="sm" onClick={onClearFilter}>
-                  Clear filter
+                  <Trans i18nKey="grafana-ui.table.filter-popup-clear">Clear filter</Trans>
                 </Button>
-              </HorizontalGroup>
+              </Stack>
             )}
-          </HorizontalGroup>
-        </VerticalGroup>
+          </Stack>
+        </Stack>
       </div>
     </ClickOutsideWrapper>
   );
