@@ -1,6 +1,7 @@
 import { css, cx } from '@emotion/css';
-import React, { CSSProperties, UIEventHandler, useCallback, useEffect, useMemo, useState } from 'react';
-import { Cell, Row, TableState } from 'react-table';
+import { CSSProperties, UIEventHandler, useCallback, useEffect, useMemo, useState } from 'react';
+import * as React from 'react';
+import { Cell, Row, TableState, HeaderGroup } from 'react-table';
 import { VariableSizeList } from 'react-window';
 import { Subscription, debounceTime } from 'rxjs';
 
@@ -12,6 +13,7 @@ import {
   FieldType,
   TimeRange,
   hasTimeField,
+  InterpolateFunction,
 } from '@grafana/data';
 import { TableCellDisplayMode, TableCellHeight } from '@grafana/schema';
 
@@ -22,8 +24,13 @@ import { usePanelContext } from '../PanelChrome';
 import { ExpandedRow, getExpandedRowHeight } from './ExpandedRow';
 import { TableCell } from './TableCell';
 import { TableStyles } from './styles';
-import { CellColors, TableFieldOptions, TableFilterActionCallback } from './types';
-import { calculateAroundPointThreshold, getCellColors, isPointTimeValAroundTableTimeVal } from './utils';
+import { CellColors, GetActionsFunction, TableFieldOptions, TableFilterActionCallback } from './types';
+import {
+  calculateAroundPointThreshold,
+  getCellColors,
+  isPointTimeValAroundTableTimeVal,
+  guessTextBoundingBox,
+} from './utils';
 
 interface RowsListProps {
   data: DataFrame;
@@ -45,6 +52,11 @@ interface RowsListProps {
   timeRange?: TimeRange;
   footerPaginationEnabled: boolean;
   initialRowIndex?: number;
+  headerGroups: HeaderGroup[];
+  longestField?: Field;
+  textWrapField?: Field;
+  getActions?: GetActionsFunction;
+  replaceVariables?: InterpolateFunction;
 }
 
 export const RowsList = (props: RowsListProps) => {
@@ -68,13 +80,38 @@ export const RowsList = (props: RowsListProps) => {
     listRef,
     enableSharedCrosshair = false,
     initialRowIndex = undefined,
+    headerGroups,
+    longestField,
+    textWrapField,
+    getActions,
+    replaceVariables,
   } = props;
 
   const [rowHighlightIndex, setRowHighlightIndex] = useState<number | undefined>(initialRowIndex);
+  if (initialRowIndex === undefined && rowHighlightIndex !== undefined) {
+    setRowHighlightIndex(undefined);
+  }
 
   const theme = useTheme2();
   const panelContext = usePanelContext();
 
+  // Create off-screen canvas for measuring rows for virtualized rendering
+  // This line is like this because Jest doesn't have OffscreenCanvas mocked
+  // nor is it a part of the jest-canvas-mock package
+  let osContext = null;
+  if (window.OffscreenCanvas !== undefined) {
+    // The canvas size is defined arbitrarily
+    // As we never actually visualize rendered content
+    // from the offscreen canvas, only perform text measurements
+    osContext = new OffscreenCanvas(256, 1024).getContext('2d');
+  }
+
+  // Set font property using theme info
+  // This will make text measurement accurate
+  if (osContext !== undefined && osContext !== null) {
+    osContext.font = `${theme.typography.fontSize}px ${theme.typography.body.fontFamily}`;
+  }
+
   const threshold = useMemo(() => {
     const timeField = data.fields.find((f) => f.type === FieldType.time);
 
@@ -87,12 +124,16 @@ export const RowsList = (props: RowsListProps) => {
 
   const onRowHover = useCallback(
     (idx: number, frame: DataFrame) => {
-      if (!panelContext || !enableSharedCrosshair || !hasTimeField(frame)) {
+      if (!panelContext || !enableSharedCrosshair) {
         return;
       }
 
       const timeField: Field = frame!.fields.find((f) => f.type === FieldType.time)!;
 
+      if (!timeField) {
+        return;
+      }
+
       panelContext.eventBus.publish(
         new DataHoverEvent({
           point: {
@@ -202,13 +243,14 @@ export const RowsList = (props: RowsListProps) => {
   );
 
   let rowBg: Function | undefined = undefined;
+  let textWrapFinal: Field | undefined;
   for (const field of data.fields) {
     // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
     const fieldOptions = field.config.custom as TableFieldOptions;
+    const cellOptionsExist = fieldOptions !== undefined && fieldOptions.cellOptions !== undefined;
 
     if (
-      fieldOptions !== undefined &&
-      fieldOptions.cellOptions !== undefined &&
+      cellOptionsExist &&
       fieldOptions.cellOptions.type === TableCellDisplayMode.ColorBackground &&
       fieldOptions.cellOptions.applyToRow
     ) {
@@ -218,6 +260,12 @@ export const RowsList = (props: RowsListProps) => {
         return colors;
       };
     }
+
+    if (textWrapField !== undefined) {
+      textWrapFinal = textWrapField;
+    } else if (longestField !== undefined) {
+      textWrapFinal = longestField;
+    }
   }
 
   const RenderRow = useCallback(
@@ -228,33 +276,56 @@ export const RowsList = (props: RowsListProps) => {
       prepareRow(row);
 
       const expandedRowStyle = tableState.expanded[row.id] ? css({ '&:hover': { background: 'inherit' } }) : {};
+      const rowExpanded = nestedDataField && tableState.expanded[row.id];
 
       if (rowHighlightIndex !== undefined && row.index === rowHighlightIndex) {
-        style = { ...style, backgroundColor: theme.components.table.rowHoverBackground };
+        style = { ...style, backgroundColor: theme.components.table.rowSelected };
         additionalProps = {
           'aria-selected': 'true',
         };
       }
 
+      // Color rows if enabled
       if (rowBg) {
         const { bgColor, textColor } = rowBg(row.index);
         style.background = bgColor;
         style.color = textColor;
+        style.borderLeft = `2px solid ${bgColor}`;
       }
 
+      // If there's a text wrapping field we set the height of it here
+      if (textWrapFinal) {
+        const visibleFields = data.fields.filter((field) => !Boolean(field.config.custom?.hidden));
+        const seriesIndex = visibleFields.findIndex((field) => field.name === textWrapFinal.name);
+        const pxLineHeight = theme.typography.body.lineHeight * theme.typography.fontSize;
+        const bbox = guessTextBoundingBox(
+          textWrapFinal.values[row.index],
+          headerGroups[0].headers[seriesIndex],
+          osContext,
+          pxLineHeight,
+          tableStyles.rowHeight,
+          tableStyles.cellPadding
+        );
+        style.height = bbox.height;
+      }
+      const { key, ...rowProps } = row.getRowProps({ style, ...additionalProps });
+
       return (
         <div
-          {...row.getRowProps({ style, ...additionalProps })}
+          key={key}
+          {...rowProps}
           className={cx(tableStyles.row, expandedRowStyle)}
-          onMouseEnter={() => onRowHover(index, data)}
+          onMouseEnter={() => onRowHover(row.index, data)}
           onMouseLeave={onRowLeave}
         >
           {/*add the nested data to the DOM first to prevent a 1px border CSS issue on the last cell of the row*/}
-          {nestedDataField && tableState.expanded[row.id] && (
+          {rowExpanded && (
             <ExpandedRow
               nestedData={nestedDataField}
               tableStyles={tableStyles}
-              rowIndex={index}
+              // Using `row.index` ensures that we pick the correct row from the original data frame even when rows in
+              // the table are sorted, since `row.index` does not change when sorting.
+              rowIndex={row.index}
               width={width}
               cellHeight={cellHeight}
             />
@@ -270,35 +341,62 @@ export const RowsList = (props: RowsListProps) => {
               timeRange={timeRange}
               frame={data}
               rowStyled={rowBg !== undefined}
+              rowExpanded={rowExpanded}
+              textWrapped={textWrapFinal !== undefined}
+              height={Number(style.height)}
+              getActions={getActions}
+              replaceVariables={replaceVariables}
             />
           ))}
         </div>
       );
     },
     [
-      cellHeight,
-      data,
-      nestedDataField,
-      onCellFilterAdded,
-      onRowHover,
-      onRowLeave,
-      prepareRow,
       rowIndexForPagination,
       rows,
+      prepareRow,
       tableState.expanded,
-      tableStyles,
-      theme.components.table.rowHoverBackground,
-      timeRange,
-      width,
+      nestedDataField,
       rowBg,
+      textWrapFinal,
+      tableStyles,
+      onRowLeave,
+      width,
+      cellHeight,
+      theme.components.table.rowSelected,
+      theme.typography.body.lineHeight,
+      theme.typography.fontSize,
+      data,
+      headerGroups,
+      osContext,
+      onRowHover,
+      onCellFilterAdded,
+      timeRange,
+      getActions,
+      replaceVariables,
     ]
   );
 
   const getItemSize = (index: number): number => {
     const indexForPagination = rowIndexForPagination(index);
     const row = rows[indexForPagination];
+
     if (tableState.expanded[row.id] && nestedDataField) {
-      return getExpandedRowHeight(nestedDataField, index, tableStyles);
+      return getExpandedRowHeight(nestedDataField, row.index, tableStyles);
+    }
+
+    if (textWrapFinal) {
+      const visibleFields = data.fields.filter((field) => !Boolean(field.config.custom?.hidden));
+      const seriesIndex = visibleFields.findIndex((field) => field.name === textWrapFinal.name);
+      const pxLineHeight = theme.typography.fontSize * theme.typography.body.lineHeight;
+      return guessTextBoundingBox(
+        textWrapFinal.values[row.index],
+        headerGroups[0].headers[seriesIndex],
+        osContext,
+        pxLineHeight,
+        tableStyles.rowHeight,
+        tableStyles.cellPadding
+      ).height;
     }
 
     return tableStyles.rowHeight;
@@ -312,22 +410,32 @@ export const RowsList = (props: RowsListProps) => {
     }
   };
 
+  // Key the virtualizer for expanded rows
+  const expandedKey = Object.keys(tableState.expanded).join('|');
+
+  // It's a hack for text wrapping.
+  // VariableSizeList component didn't know that we manually set row height.
+  // So we need to reset the list when the rows high changes.
+  useEffect(() => {
+    if (listRef.current) {
+      listRef.current.resetAfterIndex(0);
+    }
+  }, [rows, listRef]);
+
   return (
-    <>
-      <CustomScrollbar onScroll={handleScroll} hideHorizontalTrack={true} scrollTop={scrollTop}>
-        <VariableSizeList
-          // This component needs an unmount/remount when row height or page changes
-          key={rowHeight + pageIndex}
-          height={listHeight}
-          itemCount={itemCount}
-          itemSize={getItemSize}
-          width={'100%'}
-          ref={listRef}
-          style={{ overflow: undefined }}
-        >
-          {({ index, style }) => RenderRow({ index, style, rowHighlightIndex })}
-        </VariableSizeList>
-      </CustomScrollbar>
-    </>
+    <CustomScrollbar onScroll={handleScroll} hideHorizontalTrack={true} scrollTop={scrollTop}>
+      <VariableSizeList
+        // This component needs an unmount/remount when row height, page changes, or expanded rows change
+        key={`${rowHeight}${pageIndex}${expandedKey}`}
+        height={listHeight}
+        itemCount={itemCount}
+        itemSize={getItemSize}
+        width={'100%'}
+        ref={listRef}
+        style={{ overflow: undefined }}
+      >
+        {({ index, style }) => RenderRow({ index, style, rowHighlightIndex })}
+      </VariableSizeList>
+    </CustomScrollbar>
   );
 };
