@@ -1,8 +1,7 @@
 import { Meta, StoryFn } from '@storybook/react';
-import React from 'react';
 
 import { StoryExample } from '../../utils/storybook/StoryExample';
-import { VerticalGroup } from '../Layout/Layout';
+import { Stack } from '../Layout/Stack/Stack';
 
 import { Text } from './Text';
 import mdx from './Text.mdx';
@@ -41,6 +40,7 @@ const meta: Meta = {
     },
     truncate: { control: 'boolean' },
     italic: { control: 'boolean' },
+    tabular: { control: 'boolean' },
     textAlignment: {
       control: 'select',
       options: ['inherit', 'initial', 'left', 'right', 'center', 'justify', undefined],
@@ -60,7 +60,7 @@ const meta: Meta = {
 
 export const Example: StoryFn = (args) => {
   return (
-    <VerticalGroup>
+    <Stack direction="column">
       <StoryExample name="Header, paragraph and span">
         <Text {...args} element="h1">
           This is a header
@@ -84,13 +84,13 @@ export const Example: StoryFn = (args) => {
           but has truncate set to true
         </Text>
       </StoryExample>
-    </VerticalGroup>
+    </Stack>
   );
 };
 
 Example.parameters = {
   controls: {
-    exclude: ['element', 'variant', 'weight', 'textAlignment', 'truncate', 'italic', 'color', 'children'],
+    exclude: ['element', 'variant', 'weight', 'textAlignment', 'truncate', 'italic', 'tabular', 'color', 'children'],
   },
 };
 
