@@ -1,21 +1,20 @@
-/** @jsxRuntime classic */
-/** @jsx jsx */
+/* eslint-disable @grafana/no-untranslated-strings */
+/** @jsxImportSource @emotion/react */
 import { css, cx } from '@emotion/css';
-import { jsx } from '@emotion/react';
 import classnames from 'classnames';
-import { Profiler, ProfilerOnRenderCallback, useState, FC } from 'react';
+import React, { Profiler, ProfilerOnRenderCallback, useState, FC } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 
 import { useStyles2, useTheme2 } from '../../themes';
 import { Button } from '../Button';
-import { VerticalGroup } from '../Layout/Layout';
+import { Stack } from '../Layout/Stack/Stack';
 
 export function EmotionPerfTest() {
   console.log('process.env.NODE_ENV', process.env.NODE_ENV);
 
   return (
-    <VerticalGroup>
+    <Stack direction="column">
       <div>Emotion performance tests</div>
       <TestScenario name="No styles" Component={NoStyles} />
       <TestScenario name="inline emotion/css" Component={InlineEmotionCSS} />
@@ -24,7 +23,7 @@ export function EmotionPerfTest() {
       <TestScenario name="useStyles with css prop" Component={UseStylesWithCSSProp} />
       <TestScenario name="useStyles with conditional css prop" Component={UseStylesWithConditionalCSS} />
       <TestScenario name="useStyles with conditional classnames" Component={UseStylesWithConditionalClassNames} />
-    </VerticalGroup>
+    </Stack>
   );
 }
 
