@@ -3,6 +3,7 @@ package v0alpha1
 import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
+	data "github.com/grafana/grafana-plugin-sdk-go/experimental/apis/data/v0alpha1"
 	common "github.com/grafana/grafana/pkg/apimachinery/apis/common/v0alpha1"
 )
 
@@ -27,29 +28,6 @@ type DashboardList struct {
 	Items []Dashboard `json:"items,omitempty"`
 }
 
-// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
-type DashboardSummary struct {
-	metav1.TypeMeta   `json:",inline"`
-	metav1.ObjectMeta `json:"metadata,omitempty"`
-
-	// The dashboard body
-	Spec DashboardSummarySpec `json:"spec,omitempty"`
-}
-
-type DashboardSummarySpec struct {
-	Title string   `json:"title"`
-	Tags  []string `json:"tags,omitempty"`
-}
-
-// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
-type DashboardSummaryList struct {
-	metav1.TypeMeta `json:",inline"`
-	// +optional
-	metav1.ListMeta `json:"metadata,omitempty"`
-
-	Items []DashboardSummary `json:"items,omitempty"`
-}
-
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
 type DashboardVersionList struct {
 	metav1.TypeMeta `json:",inline"`
@@ -89,11 +67,80 @@ type VersionsQueryOptions struct {
 	Version int64 `json:"version,omitempty"`
 }
 
-// Information about how the requesting user can use a given dashboard
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
-type DashboardAccessInfo struct {
+type LibraryPanel struct {
 	metav1.TypeMeta `json:",inline"`
+	// Standard object's metadata
+	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
+	// +optional
+	metav1.ObjectMeta `json:"metadata,omitempty"`
 
+	// Panel properties
+	Spec LibraryPanelSpec `json:"spec"`
+
+	// Status will show errors
+	Status *LibraryPanelStatus `json:"status,omitempty"`
+}
+
+// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
+type LibraryPanelList struct {
+	metav1.TypeMeta `json:",inline"`
+	// +optional
+	metav1.ListMeta `json:"metadata,omitempty"`
+
+	Items []LibraryPanel `json:"items,omitempty"`
+}
+
+type LibraryPanelSpec struct {
+	// The panel type
+	Type string `json:"type"`
+
+	// The panel type
+	PluginVersion string `json:"pluginVersion,omitempty"`
+
+	// The panel title
+	Title string `json:"title,omitempty"`
+
+	// Library panel description
+	Description string `json:"description,omitempty"`
+
+	// The options schema depends on the panel type
+	Options common.Unstructured `json:"options"`
+
+	// The fieldConfig schema depends on the panel type
+	FieldConfig common.Unstructured `json:"fieldConfig"`
+
+	// The default datasource type
+	Datasource *data.DataSourceRef `json:"datasource,omitempty"`
+
+	// The datasource queries
+	// +listType=set
+	Targets []data.DataQuery `json:"targets,omitempty"`
+}
+
+type LibraryPanelStatus struct {
+	// Translation warnings (mostly things that were in SQL columns but not found in the saved body)
+	Warnings []string `json:"warnings,omitempty"`
+
+	// The properties previously stored in SQL that are not included in this model
+	Missing common.Unstructured `json:"missing,omitempty"`
+}
+
+// This is like the legacy DTO where access and metadata are all returned in a single call
+// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
+type DashboardWithAccessInfo struct {
+	Dashboard `json:",inline"`
+
+	Access DashboardAccess `json:"access"`
+}
+
+// Information about how the requesting user can use a given dashboard
+type DashboardAccess struct {
+	// Metadata fields
+	Slug string `json:"slug,omitempty"`
+	Url  string `json:"url,omitempty"`
+
+	// The permissions part
 	CanSave                bool                  `json:"canSave"`
 	CanEdit                bool                  `json:"canEdit"`
 	CanAdmin               bool                  `json:"canAdmin"`
