@@ -2,9 +2,10 @@ package metrics
 
 import (
 	"context"
-	"errors"
+	"fmt"
 	"regexp"
 	"sort"
+	"strings"
 
 	"github.com/prometheus/client_golang/prometheus"
 	dto "github.com/prometheus/client_model/go"
@@ -25,12 +26,13 @@ func (lw *logWrapper) Println(v ...any) {
 	lw.logger.Info("graphite metric bridge", v...)
 }
 
-func ProvideService(cfg *setting.Cfg, reg prometheus.Registerer) (*InternalMetricsService, error) {
+func ProvideService(cfg *setting.Cfg, reg prometheus.Registerer, gatherer prometheus.Gatherer) (*InternalMetricsService, error) {
 	initMetricVars(reg)
 	initFrontendMetrics(reg)
 
 	s := &InternalMetricsService{
-		Cfg: cfg,
+		Cfg:      cfg,
+		gatherer: gatherer,
 	}
 	return s, s.readSettings()
 }
@@ -40,6 +42,7 @@ type InternalMetricsService struct {
 
 	intervalSeconds int64
 	graphiteCfg     *graphitebridge.Config
+	gatherer        prometheus.Gatherer
 }
 
 func (im *InternalMetricsService) Run(ctx context.Context) error {
@@ -65,7 +68,7 @@ func ProvideRegisterer() prometheus.Registerer {
 
 func ProvideGatherer() prometheus.Gatherer {
 	k8sGatherer := newAddPrefixWrapper(legacyregistry.DefaultGatherer)
-	return newMultiRegistry(k8sGatherer, prometheus.DefaultGatherer)
+	return NewMultiRegistry(k8sGatherer, prometheus.DefaultGatherer)
 }
 
 func ProvideRegistererForTest() prometheus.Registerer {
@@ -108,7 +111,7 @@ func (g *addPrefixWrapper) Gather() ([]*dto.MetricFamily, error) {
 			*m.Name = "grafana_" + *m.Name
 			// since we are modifying the name, we need to check for duplicates in the gatherer
 			if _, exists := names[*m.Name]; exists {
-				return nil, errors.New("duplicate metric name: " + *m.Name)
+				return nil, fmt.Errorf("duplicate metric name: %s", *m.Name)
 			}
 		}
 		// keep track of names to detect duplicates
@@ -124,7 +127,7 @@ type multiRegistry struct {
 	gatherers []prometheus.Gatherer
 }
 
-func newMultiRegistry(gatherers ...prometheus.Gatherer) *multiRegistry {
+func NewMultiRegistry(gatherers ...prometheus.Gatherer) *multiRegistry {
 	return &multiRegistry{
 		gatherers: gatherers,
 	}
@@ -140,11 +143,20 @@ func (r *multiRegistry) Gather() (mfs []*dto.MetricFamily, err error) {
 
 		for i := 0; i < len(mf); i++ {
 			m := mf[i]
+			_, exists := names[*m.Name]
 			// prevent duplicate metric names
-			if _, exists := names[*m.Name]; !exists {
-				names[*m.Name] = struct{}{}
-				mfs = append(mfs, m)
+			if exists {
+				// we can skip go_ and process_ metrics without returning an error
+				// because they are known to be duplicates in both
+				// the k8s and prometheus gatherers.
+				if strings.HasPrefix(*m.Name, "go_") || strings.HasPrefix(*m.Name, "process_") {
+					continue
+				}
+				errs = append(errs, fmt.Errorf("duplicate metric name: %s", *m.Name))
+				continue
 			}
+			names[*m.Name] = struct{}{}
+			mfs = append(mfs, m)
 		}
 	}
 
