@@ -23,7 +23,7 @@ import (
 	"github.com/grafana/grafana/pkg/infra/tracing"
 	"github.com/grafana/grafana/pkg/infra/usagestats"
 	"github.com/grafana/grafana/pkg/services/accesscontrol/acimpl"
-	"github.com/grafana/grafana/pkg/services/accesscontrol/actest"
+	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/supportbundles/supportbundlestest"
 	"github.com/grafana/grafana/pkg/setting"
 	"github.com/grafana/grafana/pkg/tests/testsuite"
@@ -83,7 +83,7 @@ func TestMetrics(t *testing.T) {
 		uss.Cfg = &setting.Cfg{
 			ReportingEnabled:     true,
 			BuildVersion:         "5.0.0",
-			AnonymousEnabled:     true,
+			Anonymous:            setting.AnonymousSettings{Enabled: true},
 			BasicAuthEnabled:     true,
 			LDAPAuthEnabled:      true,
 			AuthProxy:            setting.AuthProxySettings{Enabled: true},
@@ -247,8 +247,7 @@ func createService(t *testing.T, sqlStore db.DB, withDB bool) *UsageStats {
 		kvstore.ProvideService(sqlStore),
 		routing.NewRouteRegister(),
 		tracing.InitializeTracerForTest(),
-		acimpl.ProvideAccessControl(cfg),
-		actest.FakeService{},
+		acimpl.ProvideAccessControl(featuremgmt.WithFeatures()),
 		supportbundlestest.NewFakeBundleService(),
 	)
 
