@@ -67,7 +67,7 @@ func TestSocialService_ProvideService(t *testing.T) {
 	cfg.Raw = iniFile
 
 	secrets := secretsfake.NewMockService(t)
-	accessControl := acimpl.ProvideAccessControl(cfg)
+	accessControl := acimpl.ProvideAccessControl(featuremgmt.WithFeatures())
 	sqlStore := db.InitTestDB(t)
 
 	ssoSettingsSvc := ssosettingsimpl.ProvideService(
@@ -92,7 +92,7 @@ func TestSocialService_ProvideService(t *testing.T) {
 				tc.setup(t, env)
 			}
 
-			socialService := ProvideService(cfg, env.features, &usagestats.UsageStatsMock{}, supportbundlestest.NewFakeBundleService(), remotecache.NewFakeStore(t), ssoSettingsSvc)
+			socialService := ProvideService(cfg, env.features, &usagestats.UsageStatsMock{}, supportbundlestest.NewFakeBundleService(), remotecache.NewFakeStore(t), nil, ssoSettingsSvc)
 			require.Equal(t, tc.expectedSocialMapLength, len(socialService.socialMap))
 
 			genericOAuthInfo := socialService.GetOAuthInfoProvider("generic_oauth")
@@ -115,7 +115,7 @@ func TestSocialService_ProvideService_GrafanaComGrafanaNet(t *testing.T) {
 			[auth.grafana_com]
 			enabled = true
 			client_id = grafanaComClientId
-			
+
 			[auth.grafananet]
 			enabled = false
 			client_id = grafanaNetClientId`,
@@ -133,7 +133,7 @@ func TestSocialService_ProvideService_GrafanaComGrafanaNet(t *testing.T) {
 			[auth.grafana_com]
 			enabled = false
 			client_id = grafanaComClientId
-			
+
 			[auth.grafananet]
 			enabled = true
 			client_id = grafanaNetClientId`,
@@ -151,7 +151,7 @@ func TestSocialService_ProvideService_GrafanaComGrafanaNet(t *testing.T) {
 			[auth.grafana_com]
 			enabled = true
 			client_id = grafanaComClientId
-			
+
 			[auth.grafananet]
 			enabled = true
 			client_id = grafanaNetClientId`,
@@ -169,7 +169,7 @@ func TestSocialService_ProvideService_GrafanaComGrafanaNet(t *testing.T) {
 			[auth.grafana_com]
 			enabled = false
 			client_id = grafanaComClientId
-			
+
 			[auth.grafananet]
 			enabled = false
 			client_id = grafanaNetClientId`,
@@ -179,10 +179,21 @@ func TestSocialService_ProvideService_GrafanaComGrafanaNet(t *testing.T) {
 
 	cfg := setting.NewCfg()
 	secrets := secretsfake.NewMockService(t)
-	accessControl := acimpl.ProvideAccessControl(cfg)
+	accessControl := acimpl.ProvideAccessControl(featuremgmt.WithFeatures())
 	sqlStore := db.InitTestDB(t)
 
-	ssoSettingsSvc := ssosettingsimpl.ProvideService(cfg, sqlStore, accessControl, routing.NewRouteRegister(), featuremgmt.WithFeatures(), secrets, &usagestats.UsageStatsMock{}, nil, nil, &licensing.OSSLicensingService{})
+	ssoSettingsSvc := ssosettingsimpl.ProvideService(
+		cfg,
+		sqlStore,
+		accessControl,
+		routing.NewRouteRegister(),
+		featuremgmt.WithFeatures(),
+		secrets,
+		&usagestats.UsageStatsMock{},
+		nil,
+		nil,
+		&licensing.OSSLicensingService{},
+	)
 
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
@@ -192,7 +203,7 @@ func TestSocialService_ProvideService_GrafanaComGrafanaNet(t *testing.T) {
 			cfg := setting.NewCfg()
 			cfg.Raw = iniFile
 
-			socialService := ProvideService(cfg, featuremgmt.WithFeatures(), &usagestats.UsageStatsMock{}, supportbundlestest.NewFakeBundleService(), remotecache.NewFakeStore(t), ssoSettingsSvc)
+			socialService := ProvideService(cfg, featuremgmt.WithFeatures(), &usagestats.UsageStatsMock{}, supportbundlestest.NewFakeBundleService(), remotecache.NewFakeStore(t), nil, ssoSettingsSvc)
 			require.EqualValues(t, tc.expectedGrafanaComOAuthInfo, socialService.GetOAuthInfoProvider("grafana_com"))
 		})
 	}
@@ -206,8 +217,11 @@ icon = signin
 enabled = true
 allow_sign_up = false
 auto_login = true
+client_authentication = test_client_authentication
 client_id = test_client_id
 client_secret = test_client_secret
+managed_identity_client_id = test_managed_identity_client_id
+federated_credential_audience = test_federated_credential_audience
 scopes = ["openid", "profile", "email"]
 empty_scopes = false
 email_attribute_name = email:primary
@@ -245,38 +259,41 @@ signout_redirect_url = https://oauth.com/signout?post_logout_redirect_uri=https:
 	require.NoError(t, err)
 
 	expectedOAuthInfo := &social.OAuthInfo{
-		Name:                    "OAuth",
-		Icon:                    "signin",
-		Enabled:                 true,
-		AllowSignup:             false,
-		AutoLogin:               true,
-		ClientId:                "test_client_id",
-		ClientSecret:            "test_client_secret",
-		Scopes:                  []string{"openid", "profile", "email"},
-		EmptyScopes:             false,
-		EmailAttributeName:      "email:primary",
-		EmailAttributePath:      "email",
-		RoleAttributePath:       "role",
-		RoleAttributeStrict:     true,
-		GroupsAttributePath:     "groups",
-		TeamIdsAttributePath:    "team_ids",
-		AuthUrl:                 "test_auth_url",
-		TokenUrl:                "test_token_url",
-		ApiUrl:                  "test_api_url",
-		TeamsUrl:                "test_teams_url",
-		AllowedDomains:          []string{"domain1.com"},
-		AllowedGroups:           []string{},
-		TlsSkipVerify:           true,
-		TlsClientCert:           "",
-		TlsClientKey:            "",
-		TlsClientCa:             "",
-		UsePKCE:                 false,
-		AuthStyle:               "",
-		AllowAssignGrafanaAdmin: true,
-		UseRefreshToken:         true,
-		SkipOrgRoleSync:         true,
-		HostedDomain:            "test_hosted_domain",
-		SignoutRedirectUrl:      "https://oauth.com/signout?post_logout_redirect_uri=https://grafana.com",
+		Name:                        "OAuth",
+		Icon:                        "signin",
+		Enabled:                     true,
+		AllowSignup:                 false,
+		AutoLogin:                   true,
+		ClientAuthentication:        "test_client_authentication",
+		ClientId:                    "test_client_id",
+		ClientSecret:                "test_client_secret",
+		ManagedIdentityClientID:     "test_managed_identity_client_id",
+		FederatedCredentialAudience: "test_federated_credential_audience",
+		Scopes:                      []string{"openid", "profile", "email"},
+		EmptyScopes:                 false,
+		EmailAttributeName:          "email:primary",
+		EmailAttributePath:          "email",
+		RoleAttributePath:           "role",
+		RoleAttributeStrict:         true,
+		GroupsAttributePath:         "groups",
+		TeamIdsAttributePath:        "team_ids",
+		AuthUrl:                     "test_auth_url",
+		TokenUrl:                    "test_token_url",
+		ApiUrl:                      "test_api_url",
+		TeamsUrl:                    "test_teams_url",
+		AllowedDomains:              []string{"domain1.com"},
+		AllowedGroups:               []string{},
+		TlsSkipVerify:               true,
+		TlsClientCert:               "",
+		TlsClientKey:                "",
+		TlsClientCa:                 "",
+		UsePKCE:                     false,
+		AuthStyle:                   "",
+		AllowAssignGrafanaAdmin:     true,
+		UseRefreshToken:             true,
+		SkipOrgRoleSync:             true,
+		HostedDomain:                "test_hosted_domain",
+		SignoutRedirectUrl:          "https://oauth.com/signout?post_logout_redirect_uri=https://grafana.com",
 		Extra: map[string]string{
 			"allowed_organizations":   "org1, org2",
 			"id_token_attribute_name": "id_token",
