@@ -7,10 +7,10 @@ import (
 	"strings"
 	"time"
 
+	"github.com/grafana/grafana/pkg/apimachinery/errutil"
 	"github.com/grafana/grafana/pkg/infra/slugify"
 	"github.com/grafana/grafana/pkg/services/annotations"
 	"github.com/grafana/grafana/pkg/services/org"
-	"github.com/grafana/grafana/pkg/util/errutil"
 )
 
 const (
@@ -26,8 +26,9 @@ var (
 // RoleRegistration stores a role and its assignments to built-in roles
 // (Viewer, Editor, Admin, Grafana Admin)
 type RoleRegistration struct {
-	Role   RoleDTO
-	Grants []string
+	Role    RoleDTO
+	Grants  []string
+	Exclude []string
 }
 
 // Role is the model for Role in RBAC.
@@ -80,6 +81,7 @@ type RoleDTO struct {
 	Group       string       `xorm:"group_name" json:"group"`
 	Permissions []Permission `json:"permissions,omitempty"`
 	Delegatable *bool        `json:"delegatable,omitempty"`
+	Mapped      bool         `json:"mapped,omitempty"`
 	Hidden      bool         `json:"hidden,omitempty"`
 
 	ID    int64 `json:"-" xorm:"pk autoincr 'id'"`
@@ -172,10 +174,11 @@ type TeamRole struct {
 }
 
 type UserRole struct {
-	ID     int64 `json:"id" xorm:"pk autoincr 'id'"`
-	OrgID  int64 `json:"orgId" xorm:"org_id"`
-	RoleID int64 `json:"roleId" xorm:"role_id"`
-	UserID int64 `json:"userId" xorm:"user_id"`
+	ID              int64  `json:"id" xorm:"pk autoincr 'id'"`
+	OrgID           int64  `json:"orgId" xorm:"org_id"`
+	RoleID          int64  `json:"roleId" xorm:"role_id"`
+	UserID          int64  `json:"userId" xorm:"user_id"`
+	GroupMappingUID string `json:"groupMappingUID" xorm:"group_mapping_uid"`
 
 	Created time.Time
 }
@@ -214,19 +217,7 @@ func (p Permission) OSSPermission() Permission {
 
 // SplitScope returns kind, attribute and Identifier
 func (p Permission) SplitScope() (string, string, string) {
-	if p.Scope == "" {
-		return "", "", ""
-	}
-
-	fragments := strings.Split(p.Scope, ":")
-	switch l := len(fragments); l {
-	case 1: // Splitting a wildcard scope "*" -> kind: "*"; attribute: "*"; identifier: "*"
-		return fragments[0], fragments[0], fragments[0]
-	case 2: // Splitting a wildcard scope with specified kind "dashboards:*" -> kind: "dashboards"; attribute: "*"; identifier: "*"
-		return fragments[0], fragments[1], fragments[1]
-	default: // Splitting a scope with all fields specified "dashboards:uid:my_dash" -> kind: "dashboards"; attribute: "uid"; identifier: "my_dash"
-		return fragments[0], fragments[1], strings.Join(fragments[2:], ":")
-	}
+	return SplitScope(p.Scope)
 }
 
 type GetUserPermissionsQuery struct {
@@ -244,10 +235,12 @@ type ResourcePermission struct {
 	RoleName         string
 	Actions          []string
 	Scope            string
-	UserId           int64
+	UserID           int64
+	UserUID          string
 	UserLogin        string
 	UserEmail        string
-	TeamId           int64
+	TeamID           int64
+	TeamUID          string
 	TeamEmail        string
 	Team             string
 	BuiltInRole      string
@@ -304,7 +297,7 @@ func (cmd *SaveExternalServiceRoleCommand) Validate() error {
 	cmd.ExternalServiceID = slugify.Slugify(cmd.ExternalServiceID)
 
 	// Check and deduplicate permissions
-	if cmd.Permissions == nil || len(cmd.Permissions) == 0 {
+	if len(cmd.Permissions) == 0 {
 		return errors.New("no permissions provided")
 	}
 	dedupMap := map[Permission]bool{}
@@ -332,6 +325,7 @@ const (
 	GlobalOrgID      = 0
 	NoOrgID          = int64(-1)
 	GeneralFolderUID = "general"
+	K6FolderUID      = "k6-app"
 	RoleGrafanaAdmin = "Grafana Admin"
 
 	// Permission actions
@@ -440,18 +434,38 @@ const (
 	ActionAlertingInstanceUpdate = "alert.instances:write"
 	ActionAlertingInstanceRead   = "alert.instances:read"
 
-	// Alerting Notification policies actions
+	ActionAlertingSilencesRead   = "alert.silences:read"
+	ActionAlertingSilencesCreate = "alert.silences:create"
+	ActionAlertingSilencesWrite  = "alert.silences:write"
+
+	// Alerting Notification actions (legacy)
 	ActionAlertingNotificationsRead  = "alert.notifications:read"
 	ActionAlertingNotificationsWrite = "alert.notifications:write"
 
+	// Alerting notifications template actions
+	ActionAlertingNotificationsTemplatesRead   = "alert.notifications.templates:read"
+	ActionAlertingNotificationsTemplatesWrite  = "alert.notifications.templates:write"
+	ActionAlertingNotificationsTemplatesDelete = "alert.notifications.templates:delete"
+
 	// Alerting notifications time interval actions
-	ActionAlertingNotificationsTimeIntervalsRead  = "alert.notifications.time-intervals:read"
-	ActionAlertingNotificationsTimeIntervalsWrite = "alert.notifications.time-intervals:write"
+	ActionAlertingNotificationsTimeIntervalsRead   = "alert.notifications.time-intervals:read"
+	ActionAlertingNotificationsTimeIntervalsWrite  = "alert.notifications.time-intervals:write"
+	ActionAlertingNotificationsTimeIntervalsDelete = "alert.notifications.time-intervals:delete"
 
 	// Alerting receiver actions
-	ActionAlertingReceiversList        = "alert.notifications.receivers:list"
-	ActionAlertingReceiversRead        = "alert.notifications.receivers:read"
-	ActionAlertingReceiversReadSecrets = "alert.notifications.receivers.secrets:read"
+	ActionAlertingReceiversList             = "alert.notifications.receivers:list"
+	ActionAlertingReceiversRead             = "alert.notifications.receivers:read"
+	ActionAlertingReceiversReadSecrets      = "alert.notifications.receivers.secrets:read"
+	ActionAlertingReceiversCreate           = "alert.notifications.receivers:create"
+	ActionAlertingReceiversUpdate           = "alert.notifications.receivers:write"
+	ActionAlertingReceiversDelete           = "alert.notifications.receivers:delete"
+	ActionAlertingReceiversTest             = "alert.notifications.receivers:test"
+	ActionAlertingReceiversPermissionsRead  = "receivers.permissions:read"
+	ActionAlertingReceiversPermissionsWrite = "receivers.permissions:write"
+
+	// Alerting routes policies actions
+	ActionAlertingRoutesRead  = "alert.notifications.routes:read"
+	ActionAlertingRoutesWrite = "alert.notifications.routes:write"
 
 	// External alerting rule actions. We can only narrow it down to writes or reads, as we don't control the atomicity in the external system.
 	ActionAlertingRuleExternalWrite = "alert.rules.external:write"
@@ -486,6 +500,9 @@ const (
 	ActionLibraryPanelsRead   = "library.panels:read"
 	ActionLibraryPanelsWrite  = "library.panels:write"
 	ActionLibraryPanelsDelete = "library.panels:delete"
+
+	// Usage stats actions
+	ActionUsageStatsRead = "server.usagestats.report:read"
 )
 
 var (
@@ -496,6 +513,8 @@ var (
 		return Scope("settings", "auth."+provider, "*")
 	}
 
+	ScopeSettingsLDAP = Scope("settings", "auth.ldap", "*")
+
 	// Annotation scopes
 	ScopeAnnotationsRoot             = "annotations"
 	ScopeAnnotationsProvider         = NewScopeProvider(ScopeAnnotationsRoot)
