@@ -10,6 +10,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/grafana/grafana/pkg/infra/db"
+	"github.com/grafana/grafana/pkg/infra/tracing"
 	"github.com/grafana/grafana/pkg/services/accesscontrol"
 	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
@@ -17,10 +18,10 @@ import (
 	"github.com/grafana/grafana/pkg/services/org/orgimpl"
 	"github.com/grafana/grafana/pkg/services/quota/quotatest"
 	"github.com/grafana/grafana/pkg/services/serviceaccounts"
-	"github.com/grafana/grafana/pkg/services/sqlstore"
 	"github.com/grafana/grafana/pkg/services/supportbundles/supportbundlestest"
 	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/services/user/userimpl"
+	"github.com/grafana/grafana/pkg/setting"
 	"github.com/grafana/grafana/pkg/tests/testsuite"
 )
 
@@ -88,7 +89,7 @@ func TestIntegrationStore_SetUserResourcePermission(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.desc, func(t *testing.T) {
-			store, _ := setupTestEnv(t)
+			store, _, _ := setupTestEnv(t)
 
 			for _, s := range test.seeds {
 				_, err := store.SetUserResourcePermission(context.Background(), test.orgID, accesscontrol.User{ID: test.userID}, s, nil)
@@ -176,7 +177,7 @@ func TestIntegrationStore_SetTeamResourcePermission(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.desc, func(t *testing.T) {
-			store, _ := setupTestEnv(t)
+			store, _, _ := setupTestEnv(t)
 
 			for _, s := range test.seeds {
 				_, err := store.SetTeamResourcePermission(context.Background(), test.orgID, test.teamID, s, nil)
@@ -264,7 +265,7 @@ func TestIntegrationStore_SetBuiltInResourcePermission(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.desc, func(t *testing.T) {
-			store, _ := setupTestEnv(t)
+			store, _, _ := setupTestEnv(t)
 
 			for _, s := range test.seeds {
 				_, err := store.SetBuiltInResourcePermission(context.Background(), test.orgID, test.builtInRole, s, nil)
@@ -339,7 +340,7 @@ func TestIntegrationStore_SetResourcePermissions(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.desc, func(t *testing.T) {
-			store, _ := setupTestEnv(t)
+			store, _, _ := setupTestEnv(t)
 
 			permissions, err := store.SetResourcePermissions(context.Background(), tt.orgID, tt.commands, ResourceHooks{})
 			require.NoError(t, err)
@@ -350,8 +351,8 @@ func TestIntegrationStore_SetResourcePermissions(t *testing.T) {
 					assert.Equal(t, accesscontrol.ResourcePermission{}, permissions[i])
 				} else {
 					assert.Len(t, permissions[i].Actions, len(c.Actions))
-					assert.Equal(t, c.TeamID, permissions[i].TeamId)
-					assert.Equal(t, c.User.ID, permissions[i].UserId)
+					assert.Equal(t, c.TeamID, permissions[i].TeamID)
+					assert.Equal(t, c.User.ID, permissions[i].UserID)
 					assert.Equal(t, c.BuiltinRole, permissions[i].BuiltInRole)
 					assert.Equal(t, accesscontrol.Scope(c.Resource, tt.resourceAttribute, c.ResourceID), permissions[i].Scope)
 				}
@@ -469,8 +470,8 @@ func TestIntegrationStore_GetResourcePermissions(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.desc, func(t *testing.T) {
-			store, sql := setupTestEnv(t)
-			orgService, err := orgimpl.ProvideService(sql, sql.Cfg, quotatest.New(false, nil))
+			store, sql, cfg := setupTestEnv(t)
+			orgService, err := orgimpl.ProvideService(sql, cfg, quotatest.New(false, nil))
 			require.NoError(t, err)
 
 			err = sql.WithDbSession(context.Background(), func(sess *db.Session) error {
@@ -508,7 +509,7 @@ func TestIntegrationStore_GetResourcePermissions(t *testing.T) {
 			})
 			require.NoError(t, err)
 
-			seedResourcePermissions(t, store, sql, orgService, tt.query.Actions, tt.query.Resource, tt.query.ResourceID, tt.query.ResourceAttribute, tt.numUsers, tt.numServiceAccounts)
+			seedResourcePermissions(t, store, sql, cfg, orgService, tt.query.Actions, tt.query.Resource, tt.query.ResourceID, tt.query.ResourceAttribute, tt.numUsers, tt.numServiceAccounts)
 
 			tt.query.User = tt.user
 			permissions, err := store.GetResourcePermissions(context.Background(), tt.user.OrgID, tt.query)
@@ -519,7 +520,7 @@ func TestIntegrationStore_GetResourcePermissions(t *testing.T) {
 }
 
 func seedResourcePermissions(
-	t *testing.T, store *store, sql *sqlstore.SQLStore, orgService org.Service,
+	t *testing.T, store *store, sql db.DB, cfg *setting.Cfg, orgService org.Service,
 	actions []string, resource, resourceID, resourceAttribute string, numUsers, numServiceAccounts int,
 ) {
 	t.Helper()
@@ -527,7 +528,10 @@ func seedResourcePermissions(
 	orgID, err := orgService.GetOrCreate(context.Background(), "test")
 	require.NoError(t, err)
 
-	usrSvc, err := userimpl.ProvideService(sql, orgService, sql.Cfg, nil, nil, quotatest.New(false, nil), supportbundlestest.NewFakeBundleService())
+	usrSvc, err := userimpl.ProvideService(
+		sql, orgService, cfg, nil, nil, tracing.InitializeTracerForTest(),
+		quotatest.New(false, nil), supportbundlestest.NewFakeBundleService(),
+	)
 	require.NoError(t, err)
 
 	create := func(login string, isServiceAccount bool) {
@@ -557,9 +561,9 @@ func seedResourcePermissions(
 	}
 }
 
-func setupTestEnv(t testing.TB) (*store, *sqlstore.SQLStore) {
-	sql := db.InitTestDB(t)
-	return NewStore(sql, featuremgmt.WithFeatures()), sql
+func setupTestEnv(t testing.TB) (*store, db.DB, *setting.Cfg) {
+	sql, cfg := db.InitTestDBWithCfg(t)
+	return NewStore(cfg, sql, featuremgmt.WithFeatures()), sql, cfg
 }
 
 func TestStore_IsInherited(t *testing.T) {
@@ -681,7 +685,7 @@ func TestIntegrationStore_DeleteResourcePermissions(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.desc, func(t *testing.T) {
-			store, _ := setupTestEnv(t)
+			store, _, _ := setupTestEnv(t)
 
 			_, err := store.SetResourcePermissions(context.Background(), 1, []SetResourcePermissionsCommand{
 				{
@@ -753,3 +757,176 @@ func retrievePermissionsHelper(store *store, t *testing.T) []orgPermission {
 	require.NoError(t, err)
 	return permissions
 }
+
+func TestStore_StoreActionSet(t *testing.T) {
+	if testing.Short() {
+		t.Skip("skipping integration test")
+	}
+
+	type actionSetTest struct {
+		desc     string
+		resource string
+		action   string
+		actions  []string
+	}
+
+	tests := []actionSetTest{
+		{
+			desc:     "should be able to store action set",
+			resource: "folders",
+			action:   "edit",
+			actions:  []string{"folders:read", "folders:write"},
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.desc, func(t *testing.T) {
+			asService := NewInMemoryActionSetStore(featuremgmt.WithFeatures(featuremgmt.FlagAccessActionSets))
+			asService.StoreActionSet(GetActionSetName(tt.resource, tt.action), tt.actions)
+
+			actionSetName := GetActionSetName(tt.resource, tt.action)
+			actionSet := asService.ResolveActionSet(actionSetName)
+			require.Equal(t, tt.actions, actionSet)
+		})
+	}
+}
+
+func TestStore_ResolveActionSet(t *testing.T) {
+	actionSetService := NewActionSetService(featuremgmt.WithFeatures(featuremgmt.FlagAccessActionSets))
+	actionSetService.StoreActionSet("folders:edit", []string{"folders:read", "folders:write", "dashboards:read", "dashboards:write"})
+	actionSetService.StoreActionSet("folders:view", []string{"folders:read", "dashboards:read"})
+	actionSetService.StoreActionSet("dashboards:view", []string{"dashboards:read"})
+
+	type actionSetTest struct {
+		desc               string
+		action             string
+		expectedActionSets []string
+	}
+
+	tests := []actionSetTest{
+		{
+			desc:               "should return empty list for an action that is not a part of any action sets",
+			action:             "datasources:query",
+			expectedActionSets: []string{},
+		},
+		{
+			desc:               "should be able to resolve one action set for the resource of the same type",
+			action:             "folders:write",
+			expectedActionSets: []string{"folders:edit"},
+		},
+		{
+			desc:               "should be able to resolve multiple action sets for the resource of the same type",
+			action:             "folders:read",
+			expectedActionSets: []string{"folders:view", "folders:edit"},
+		},
+		{
+			desc:               "should be able to resolve multiple action sets for the resource of a different type",
+			action:             "dashboards:read",
+			expectedActionSets: []string{"folders:view", "folders:edit", "dashboards:view"},
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.desc, func(t *testing.T) {
+			actionSets := actionSetService.ResolveAction(tt.action)
+			require.ElementsMatch(t, tt.expectedActionSets, actionSets)
+		})
+	}
+}
+
+func TestStore_ExpandActions(t *testing.T) {
+	actionSetService := NewActionSetService(featuremgmt.WithFeatures(featuremgmt.FlagAccessActionSets))
+	actionSetService.StoreActionSet("folders:edit", []string{"folders:read", "folders:write", "dashboards:read", "dashboards:write"})
+	actionSetService.StoreActionSet("folders:view", []string{"folders:read", "dashboards:read"})
+	actionSetService.StoreActionSet("dashboards:view", []string{"dashboards:read"})
+
+	type actionSetTest struct {
+		desc                string
+		permissions         []accesscontrol.Permission
+		expectedPermissions []accesscontrol.Permission
+	}
+
+	tests := []actionSetTest{
+		{
+			desc:                "should return empty list if no permissions are passed in",
+			permissions:         []accesscontrol.Permission{},
+			expectedPermissions: []accesscontrol.Permission{},
+		},
+		{
+			desc: "should return unchanged permissions if none of actions are part of any action sets",
+			permissions: []accesscontrol.Permission{
+				{
+					Action: "datasources:create",
+				},
+				{
+					Action: "users:read",
+					Scope:  "users:*",
+				},
+			},
+			expectedPermissions: []accesscontrol.Permission{
+				{
+					Action: "datasources:create",
+				},
+				{
+					Action: "users:read",
+					Scope:  "users:*",
+				},
+			},
+		},
+		{
+			desc: "should return unchanged permissions if none of actions are part of any action sets",
+			permissions: []accesscontrol.Permission{
+				{
+					Action: "datasources:create",
+				},
+				{
+					Action: "users:read",
+					Scope:  "users:*",
+				},
+			},
+			expectedPermissions: []accesscontrol.Permission{
+				{
+					Action: "datasources:create",
+				},
+				{
+					Action: "users:read",
+					Scope:  "users:*",
+				},
+			},
+		},
+		{
+			desc: "should be able to expand one permission and leave others unchanged",
+			permissions: []accesscontrol.Permission{
+				{
+					Action: "folders:view",
+					Scope:  "folders:uid:1",
+				},
+				{
+					Action: "users:read",
+					Scope:  "users:*",
+				},
+			},
+			expectedPermissions: []accesscontrol.Permission{
+				{
+					Action: "folders:read",
+					Scope:  "folders:uid:1",
+				},
+				{
+					Action: "dashboards:read",
+					Scope:  "folders:uid:1",
+				},
+				{
+					Action: "users:read",
+					Scope:  "users:*",
+				},
+			},
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.desc, func(t *testing.T) {
+			permissions := actionSetService.ExpandActionSets(tt.permissions)
+			require.ElementsMatch(t, tt.expectedPermissions, permissions)
+		})
+	}
+}
