@@ -6,6 +6,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/grafana/authlib/claims"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
@@ -13,6 +14,9 @@ import (
 	"github.com/grafana/grafana/pkg/services/auth"
 	"github.com/grafana/grafana/pkg/services/auth/authtest"
 	"github.com/grafana/grafana/pkg/services/authn"
+	"github.com/grafana/grafana/pkg/services/login"
+	"github.com/grafana/grafana/pkg/services/login/authinfotest"
+	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/setting"
 )
 
@@ -26,7 +30,7 @@ func TestSession_Test(t *testing.T) {
 	cfg := setting.NewCfg()
 	cfg.LoginCookieName = ""
 	cfg.LoginMaxLifetime = 20 * time.Second
-	s := ProvideSession(cfg, &authtest.FakeUserAuthTokenService{})
+	s := ProvideSession(cfg, &authtest.FakeUserAuthTokenService{}, &authinfotest.FakeService{})
 
 	disabled := s.Test(context.Background(), &authn.Request{HTTPRequest: validHTTPReq})
 	assert.False(t, disabled)
@@ -60,7 +64,8 @@ func TestSession_Authenticate(t *testing.T) {
 	}
 
 	type fields struct {
-		sessionService auth.UserTokenService
+		authInfoService login.AuthInfoService
+		sessionService  auth.UserTokenService
 	}
 	type args struct {
 		r *authn.Request
@@ -75,7 +80,8 @@ func TestSession_Authenticate(t *testing.T) {
 		{
 			name: "cookie not found",
 			fields: fields{
-				sessionService: &authtest.FakeUserAuthTokenService{},
+				sessionService:  &authtest.FakeUserAuthTokenService{},
+				authInfoService: &authinfotest.FakeService{},
 			},
 			args:    args{r: &authn.Request{HTTPRequest: &http.Request{}}},
 			wantID:  nil,
@@ -87,10 +93,12 @@ func TestSession_Authenticate(t *testing.T) {
 				sessionService: &authtest.FakeUserAuthTokenService{LookupTokenProvider: func(ctx context.Context, unhashedToken string) (*auth.UserToken, error) {
 					return validToken, nil
 				}},
+				authInfoService: &authinfotest.FakeService{ExpectedUserAuth: &login.UserAuth{}},
 			},
 			args: args{r: &authn.Request{HTTPRequest: validHTTPReq}},
 			wantID: &authn.Identity{
-				ID:           "user:1",
+				ID:           "1",
+				Type:         claims.TypeUser,
 				SessionToken: validToken,
 				ClientParams: authn.ClientParams{
 					SyncPermissions: true,
@@ -108,6 +116,7 @@ func TestSession_Authenticate(t *testing.T) {
 						RotatedAt:     time.Now().Add(-11 * time.Minute).Unix(),
 					}, nil
 				}},
+				authInfoService: &authinfotest.FakeService{ExpectedUserAuth: &login.UserAuth{}},
 			},
 			args:    args{r: &authn.Request{HTTPRequest: validHTTPReq}},
 			wantErr: true,
@@ -118,10 +127,13 @@ func TestSession_Authenticate(t *testing.T) {
 				sessionService: &authtest.FakeUserAuthTokenService{LookupTokenProvider: func(ctx context.Context, unhashedToken string) (*auth.UserToken, error) {
 					return validToken, nil
 				}},
+				authInfoService: &authinfotest.FakeService{ExpectedUserAuth: &login.UserAuth{}},
 			},
 			args: args{r: &authn.Request{HTTPRequest: validHTTPReq}},
 			wantID: &authn.Identity{
-				ID:           "user:1",
+				ID:   "1",
+				Type: claims.TypeUser,
+
 				SessionToken: validToken,
 				ClientParams: authn.ClientParams{
 					SyncPermissions: true,
@@ -130,6 +142,50 @@ func TestSession_Authenticate(t *testing.T) {
 			},
 			wantErr: false,
 		},
+		{
+			name: "should set authID and authenticated by for externally authenticated user",
+			fields: fields{
+				sessionService: &authtest.FakeUserAuthTokenService{LookupTokenProvider: func(ctx context.Context, unhashedToken string) (*auth.UserToken, error) {
+					return validToken, nil
+				}},
+				authInfoService: &authinfotest.FakeService{ExpectedUserAuth: &login.UserAuth{AuthId: "1", AuthModule: "oauth_azuread"}},
+			},
+			args: args{r: &authn.Request{HTTPRequest: validHTTPReq}},
+			wantID: &authn.Identity{
+				ID:              "1",
+				Type:            claims.TypeUser,
+				AuthID:          "1",
+				AuthenticatedBy: "oauth_azuread",
+				SessionToken:    validToken,
+
+				ClientParams: authn.ClientParams{
+					SyncPermissions: true,
+					FetchSyncedUser: true,
+				},
+			},
+			wantErr: false,
+		},
+		{
+			name: "should not set authID and authenticated by when no auth info exists for user",
+			fields: fields{
+				sessionService: &authtest.FakeUserAuthTokenService{LookupTokenProvider: func(ctx context.Context, unhashedToken string) (*auth.UserToken, error) {
+					return validToken, nil
+				}},
+				authInfoService: &authinfotest.FakeService{ExpectedError: user.ErrUserNotFound},
+			},
+			args: args{r: &authn.Request{HTTPRequest: validHTTPReq}},
+			wantID: &authn.Identity{
+				ID:           "1",
+				Type:         claims.TypeUser,
+				SessionToken: validToken,
+
+				ClientParams: authn.ClientParams{
+					SyncPermissions: true,
+					FetchSyncedUser: true,
+				},
+			},
+			wantErr: false,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -137,7 +193,7 @@ func TestSession_Authenticate(t *testing.T) {
 			cfg.LoginCookieName = cookieName
 			cfg.TokenRotationIntervalMinutes = 10
 			cfg.LoginMaxLifetime = 20 * time.Second
-			s := ProvideSession(cfg, tt.fields.sessionService)
+			s := ProvideSession(cfg, tt.fields.sessionService, tt.fields.authInfoService)
 
 			got, err := s.Authenticate(context.Background(), tt.args.r)
 			require.True(t, (err != nil) == tt.wantErr, err)
