@@ -4,11 +4,11 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/components/simplejson"
 	"github.com/grafana/grafana/pkg/infra/metrics"
 	"github.com/grafana/grafana/pkg/infra/slugify"
 	"github.com/grafana/grafana/pkg/models"
-	"github.com/grafana/grafana/pkg/services/auth/identity"
 	"github.com/grafana/grafana/pkg/services/dashboards/dashboardaccess"
 	"github.com/grafana/grafana/pkg/services/folder"
 	"github.com/grafana/grafana/pkg/services/org"
@@ -36,6 +36,7 @@ type Dashboard struct {
 
 	Created time.Time
 	Updated time.Time
+	Deleted time.Time
 
 	UpdatedBy int64
 	CreatedBy int64
@@ -209,6 +210,10 @@ type SaveDashboardCommand struct {
 	UpdatedAt time.Time
 }
 
+type RestoreDeletedDashboardCommand struct {
+	FolderUID string `json:"folderUid" xorm:"folder_uid"`
+}
+
 type DashboardProvisioning struct {
 	ID          int64 `xorm:"pk autoincr 'id'"`
 	DashboardID int64 `xorm:"dashboard_id"`
@@ -247,13 +252,16 @@ type DeleteOrphanedProvisionedDashboardsCommand struct {
 //
 // Multiple constraints can be combined.
 type GetDashboardQuery struct {
-	ID    int64
-	UID   string
+	ID  int64
+	UID string
+	// Deprecated: this is no-longer a unique constraint and should not be used
 	Title *string
 	// Deprecated: use FolderUID instead
 	FolderID  *int64
 	FolderUID *string
 	OrgID     int64
+
+	IncludeDeleted bool // only supported when using unified storage
 }
 
 type DashboardTagCloudItem struct {
@@ -297,6 +305,7 @@ type SaveDashboardDTO struct {
 type DashboardSearchProjection struct {
 	ID       int64  `xorm:"id"`
 	UID      string `xorm:"uid"`
+	OrgID    int64  `xorm:"org_id"`
 	Title    string
 	Slug     string
 	Term     string
@@ -307,6 +316,8 @@ type DashboardSearchProjection struct {
 	FolderSlug  string
 	FolderTitle string
 	SortMeta    int64
+	Tags        []string
+	Deleted     *time.Time
 }
 
 const (
@@ -381,10 +392,12 @@ type DashboardACLInfoDTO struct {
 	Updated time.Time `json:"updated"`
 
 	UserID         int64                          `json:"userId" xorm:"user_id"`
+	UserUID        string                         `json:"userUid"`
 	UserLogin      string                         `json:"userLogin"`
 	UserEmail      string                         `json:"userEmail"`
 	UserAvatarURL  string                         `json:"userAvatarUrl" xorm:"user_avatar_url"`
 	TeamID         int64                          `json:"teamId" xorm:"team_id"`
+	TeamUID        string                         `json:"teamUid"`
 	TeamEmail      string                         `json:"teamEmail"`
 	TeamAvatarURL  string                         `json:"teamAvatarUrl" xorm:"team_avatar_url"`
 	Team           string                         `json:"team"`
@@ -414,6 +427,15 @@ type FindPersistedDashboardsQuery struct {
 	Page       int64
 	Permission dashboardaccess.PermissionType
 	Sort       model.SortOption
+	IsDeleted  bool
+
+	ProvisionedRepo       string
+	ProvisionedPath       string
+	ProvisionedReposNotIn []string
 
 	Filters []any
+
+	// Skip access control checks. This field is used by OpenFGA search implementation.
+	// Should not be used anywhere else.
+	SkipAccessControlFilter bool
 }
