@@ -31,6 +31,7 @@ type Scheduler struct {
 	UpdateSchedulableAlertRulesDuration prometheus.Histogram
 	Ticker                              *ticker.Metrics
 	EvaluationMissed                    *prometheus.CounterVec
+	SimplifiedEditorRules               *prometheus.GaugeVec
 }
 
 func NewSchedulerMetrics(r prometheus.Registerer) *Scheduler {
@@ -121,15 +122,14 @@ func NewSchedulerMetrics(r prometheus.Registerer) *Scheduler {
 			},
 			[]string{"org"},
 		),
-		// TODO: partition on rule group as well as tenant, similar to loki|cortex.
 		GroupRules: promauto.With(r).NewGaugeVec(
 			prometheus.GaugeOpts{
 				Namespace: Namespace,
 				Subsystem: Subsystem,
 				Name:      "rule_group_rules",
-				Help:      "The number of alert rules that are scheduled, both active and paused.",
+				Help:      "The number of alert rules that are scheduled, by type and state.",
 			},
-			[]string{"org", "state"},
+			[]string{"org", "type", "state", "rule_group"},
 		),
 		Groups: promauto.With(r).NewGaugeVec(
 			prometheus.GaugeOpts{
@@ -183,5 +183,14 @@ func NewSchedulerMetrics(r prometheus.Registerer) *Scheduler {
 			},
 			[]string{"org", "name"},
 		),
+		SimplifiedEditorRules: promauto.With(r).NewGaugeVec(
+			prometheus.GaugeOpts{
+				Namespace: Namespace,
+				Subsystem: Subsystem,
+				Name:      "simplified_editor_rules",
+				Help:      "The number of alert rules using simplified editor settings.",
+			},
+			[]string{"org", "setting"},
+		),
 	}
 }
