@@ -18,8 +18,9 @@ const GroupByAll = "..."
 var DefaultNotificationSettingsGroupBy = []string{FolderTitleLabel, model.AlertNameLabel}
 
 type ListNotificationSettingsQuery struct {
-	OrgID        int64
-	ReceiverName string
+	OrgID            int64
+	ReceiverName     string
+	TimeIntervalName string
 }
 
 // NotificationSettings represents the settings for sending notifications for a single AlertRule. It is used to
@@ -34,6 +35,10 @@ type NotificationSettings struct {
 	MuteTimeIntervals []string        `json:"mute_time_intervals,omitempty"`
 }
 
+func (s *NotificationSettings) GetUID() string {
+	return NameToUid(s.Receiver)
+}
+
 // NormalizedGroupBy returns a consistent and ordered GroupBy.
 //   - If the GroupBy is empty, it returns nil so that the parent group can be inherited.
 //   - If the GroupBy contains the special label '...', it returns only '...'.
@@ -81,11 +86,11 @@ func (s *NotificationSettings) Validate() error {
 	if s.GroupWait != nil && *s.GroupWait < 0 {
 		return errors.New("group wait must be a positive duration")
 	}
-	if s.GroupInterval != nil && *s.GroupInterval < 0 {
-		return errors.New("group interval must be a positive duration")
+	if s.GroupInterval != nil && *s.GroupInterval <= 0 {
+		return errors.New("group interval must be greater than zero")
 	}
-	if s.RepeatInterval != nil && *s.RepeatInterval < 0 {
-		return errors.New("repeat interval must be a positive duration")
+	if s.RepeatInterval != nil && *s.RepeatInterval <= 0 {
+		return errors.New("repeat interval must be greater than zero")
 	}
 	return nil
 }
