@@ -9,12 +9,13 @@ import (
 
 	"github.com/benbjohnson/clock"
 	"github.com/go-openapi/strfmt"
-	alertingModels "github.com/grafana/alerting/models"
 	"github.com/grafana/grafana-plugin-sdk-go/data"
 	"github.com/prometheus/alertmanager/api/v2/models"
 	"github.com/prometheus/common/model"
 	"github.com/stretchr/testify/require"
 
+	alertingModels "github.com/grafana/alerting/models"
+
 	"github.com/grafana/grafana/pkg/services/ngalert/eval"
 	ngModels "github.com/grafana/grafana/pkg/services/ngalert/models"
 	"github.com/grafana/grafana/pkg/util"
@@ -267,7 +268,9 @@ func TestStateToPostableAlertFromNodataError(t *testing.T) {
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
 			alertState := randomTransition(tc.from, tc.to)
-			alertState.Resolved = tc.resolved
+			if tc.resolved {
+				alertState.ResolvedAt = &alertState.LastEvaluationTime
+			}
 			alertState.Labels = data.Labels(standardLabels)
 			result := StateToPostableAlert(alertState, appURL)
 			require.Equal(t, tc.expectedLabels, result.Labels)
@@ -339,7 +342,7 @@ func randomTransition(from, to eval.State) StateTransition {
 			EndsAt:             randomTimeInFuture(),
 			LastEvaluationTime: randomTimeInPast(),
 			EvaluationDuration: randomDuration(),
-			LastSentAt:         randomTimeInPast(),
+			LastSentAt:         util.Pointer(randomTimeInPast()),
 			Annotations:        make(map[string]string),
 			Labels:             make(map[string]string),
 			Values:             make(map[string]float64),
