@@ -10,6 +10,7 @@ import (
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/stretchr/testify/require"
+	"go.opentelemetry.io/otel/trace"
 
 	"github.com/grafana/grafana/pkg/infra/tracing"
 	"github.com/grafana/grafana/pkg/plugins"
@@ -25,7 +26,6 @@ import (
 	"github.com/grafana/grafana/pkg/plugins/manager/registry"
 	"github.com/grafana/grafana/pkg/plugins/manager/signature"
 	"github.com/grafana/grafana/pkg/plugins/manager/sources"
-	"github.com/grafana/grafana/pkg/plugins/pfs"
 	"github.com/grafana/grafana/pkg/plugins/pluginscdn"
 	"github.com/grafana/grafana/pkg/services/org"
 	"github.com/grafana/grafana/pkg/services/pluginsintegration/pipeline"
@@ -63,7 +63,7 @@ func TestLoader_Load(t *testing.T) {
 		cfg          *config.PluginManagementCfg
 		pluginPaths  []string
 		want         []*plugins.Plugin
-		pluginErrors map[string]*plugins.SignatureError
+		pluginErrors map[string]*plugins.Error
 	}{
 		{
 			name:        "Load a Core plugin",
@@ -82,6 +82,7 @@ func TestLoader_Load(t *testing.T) {
 								URL:  "https://grafana.com",
 							},
 							Description: "Data source for Amazon AWS monitoring service",
+							Keywords:    []string{"aws", "amazon"},
 							Logos: plugins.Logos{
 								Small: "public/app/plugins/datasource/cloudwatch/img/amazon-web-services.png",
 								Large: "public/app/plugins/datasource/cloudwatch/img/amazon-web-services.png",
@@ -97,6 +98,15 @@ func TestLoader_Load(t *testing.T) {
 						Dependencies: plugins.Dependencies{
 							GrafanaVersion: "*",
 							Plugins:        []plugins.Dependency{},
+							Extensions: plugins.ExtensionsDependencies{
+								ExposedComponents: []string{},
+							},
+						},
+						Extensions: plugins.Extensions{
+							AddedLinks:        []plugins.AddedLink{},
+							AddedComponents:   []plugins.AddedComponent{},
+							ExposedComponents: []plugins.ExposedComponent{},
+							ExtensionPoints:   []plugins.ExtensionPoint{},
 						},
 						Category:     "cloud",
 						Annotations:  true,
@@ -140,6 +150,15 @@ func TestLoader_Load(t *testing.T) {
 						Dependencies: plugins.Dependencies{
 							GrafanaVersion: "*",
 							Plugins:        []plugins.Dependency{},
+							Extensions: plugins.ExtensionsDependencies{
+								ExposedComponents: []string{},
+							},
+						},
+						Extensions: plugins.Extensions{
+							AddedLinks:        []plugins.AddedLink{},
+							AddedComponents:   []plugins.AddedComponent{},
+							ExposedComponents: []plugins.ExposedComponent{},
+							ExtensionPoints:   []plugins.ExtensionPoint{},
 						},
 						Executable: "test",
 						Backend:    true,
@@ -194,35 +213,48 @@ func TestLoader_Load(t *testing.T) {
 								{Type: "datasource", ID: "graphite", Name: "Graphite", Version: "1.0.0"},
 								{Type: "panel", ID: "graph", Name: "Graph", Version: "1.0.0"},
 							},
+							Extensions: plugins.ExtensionsDependencies{
+								ExposedComponents: []string{},
+							},
 						},
 						Includes: []*plugins.Includes{
 							{
-								Name: "Nginx Connections",
-								Path: "dashboards/connections.json",
-								Type: "dashboard",
-								Role: org.RoleViewer,
-								Slug: "nginx-connections",
+								Name:   "Nginx Connections",
+								Path:   "dashboards/connections.json",
+								Type:   "dashboard",
+								Role:   org.RoleViewer,
+								Action: plugins.ActionAppAccess,
+								Slug:   "nginx-connections",
 							},
 							{
-								Name: "Nginx Memory",
-								Path: "dashboards/memory.json",
-								Type: "dashboard",
-								Role: org.RoleViewer,
-								Slug: "nginx-memory",
+								Name:   "Nginx Memory",
+								Path:   "dashboards/memory.json",
+								Type:   "dashboard",
+								Role:   org.RoleViewer,
+								Action: plugins.ActionAppAccess,
+								Slug:   "nginx-memory",
 							},
 							{
-								Name: "Nginx Panel",
-								Type: string(plugins.TypePanel),
-								Role: org.RoleViewer,
-								Slug: "nginx-panel",
+								Name:   "Nginx Panel",
+								Type:   string(plugins.TypePanel),
+								Role:   org.RoleViewer,
+								Action: plugins.ActionAppAccess,
+								Slug:   "nginx-panel",
 							},
 							{
-								Name: "Nginx Datasource",
-								Type: string(plugins.TypeDataSource),
-								Role: org.RoleViewer,
-								Slug: "nginx-datasource",
+								Name:   "Nginx Datasource",
+								Type:   string(plugins.TypeDataSource),
+								Role:   org.RoleViewer,
+								Action: plugins.ActionAppAccess,
+								Slug:   "nginx-datasource",
 							},
 						},
+						Extensions: plugins.Extensions{
+							AddedLinks:        []plugins.AddedLink{},
+							AddedComponents:   []plugins.AddedComponent{},
+							ExposedComponents: []plugins.ExposedComponent{},
+							ExtensionPoints:   []plugins.ExtensionPoint{},
+						},
 					},
 					Class:         plugins.ClassExternal,
 					Module:        "public/plugins/test-app/module.js",
@@ -261,6 +293,15 @@ func TestLoader_Load(t *testing.T) {
 						Dependencies: plugins.Dependencies{
 							GrafanaVersion: "*",
 							Plugins:        []plugins.Dependency{},
+							Extensions: plugins.ExtensionsDependencies{
+								ExposedComponents: []string{},
+							},
+						},
+						Extensions: plugins.Extensions{
+							AddedLinks:        []plugins.AddedLink{},
+							AddedComponents:   []plugins.AddedComponent{},
+							ExposedComponents: []plugins.ExposedComponent{},
+							ExtensionPoints:   []plugins.ExtensionPoint{},
 						},
 						Backend: true,
 						State:   plugins.ReleaseStateAlpha,
@@ -279,7 +320,7 @@ func TestLoader_Load(t *testing.T) {
 			cfg:         &config.PluginManagementCfg{},
 			pluginPaths: []string{filepath.Join(testDataDir(t), "unsigned-datasource")},
 			want:        []*plugins.Plugin{},
-			pluginErrors: map[string]*plugins.SignatureError{
+			pluginErrors: map[string]*plugins.Error{
 				"test-datasource": {
 					PluginID:        "test-datasource",
 					SignatureStatus: plugins.SignatureStatusUnsigned,
@@ -313,6 +354,15 @@ func TestLoader_Load(t *testing.T) {
 						Dependencies: plugins.Dependencies{
 							GrafanaVersion: "*",
 							Plugins:        []plugins.Dependency{},
+							Extensions: plugins.ExtensionsDependencies{
+								ExposedComponents: []string{},
+							},
+						},
+						Extensions: plugins.Extensions{
+							AddedLinks:        []plugins.AddedLink{},
+							AddedComponents:   []plugins.AddedComponent{},
+							ExposedComponents: []plugins.ExposedComponent{},
+							ExtensionPoints:   []plugins.ExtensionPoint{},
 						},
 						Backend: true,
 						State:   plugins.ReleaseStateAlpha,
@@ -331,7 +381,7 @@ func TestLoader_Load(t *testing.T) {
 			cfg:         &config.PluginManagementCfg{},
 			pluginPaths: []string{filepath.Join(testDataDir(t), "lacking-files")},
 			want:        []*plugins.Plugin{},
-			pluginErrors: map[string]*plugins.SignatureError{
+			pluginErrors: map[string]*plugins.Error{
 				"test-datasource": {
 					PluginID:        "test-datasource",
 					SignatureStatus: plugins.SignatureStatusInvalid,
@@ -346,7 +396,7 @@ func TestLoader_Load(t *testing.T) {
 			},
 			pluginPaths: []string{filepath.Join(testDataDir(t), "lacking-files")},
 			want:        []*plugins.Plugin{},
-			pluginErrors: map[string]*plugins.SignatureError{
+			pluginErrors: map[string]*plugins.Error{
 				"test-datasource": {
 					PluginID:        "test-datasource",
 					SignatureStatus: plugins.SignatureStatusInvalid,
@@ -361,7 +411,7 @@ func TestLoader_Load(t *testing.T) {
 			},
 			pluginPaths: []string{filepath.Join(testDataDir(t), "invalid-v2-missing-file")},
 			want:        []*plugins.Plugin{},
-			pluginErrors: map[string]*plugins.SignatureError{
+			pluginErrors: map[string]*plugins.Error{
 				"test-datasource": {
 					PluginID:        "test-datasource",
 					SignatureStatus: plugins.SignatureStatusModified,
@@ -376,7 +426,7 @@ func TestLoader_Load(t *testing.T) {
 			},
 			pluginPaths: []string{filepath.Join(testDataDir(t), "invalid-v2-extra-file")},
 			want:        []*plugins.Plugin{},
-			pluginErrors: map[string]*plugins.SignatureError{
+			pluginErrors: map[string]*plugins.Error{
 				"test-datasource": {
 					PluginID:        "test-datasource",
 					SignatureStatus: plugins.SignatureStatusModified,
@@ -418,10 +468,19 @@ func TestLoader_Load(t *testing.T) {
 							GrafanaDependency: ">=8.0.0",
 							GrafanaVersion:    "*",
 							Plugins:           []plugins.Dependency{},
+							Extensions: plugins.ExtensionsDependencies{
+								ExposedComponents: []string{},
+							},
+						},
+						Extensions: plugins.Extensions{
+							AddedLinks:        []plugins.AddedLink{},
+							AddedComponents:   []plugins.AddedComponent{},
+							ExposedComponents: []plugins.ExposedComponent{},
+							ExtensionPoints:   []plugins.ExtensionPoint{},
 						},
 						Includes: []*plugins.Includes{
-							{Name: "Nginx Memory", Path: "dashboards/memory.json", Type: "dashboard", Role: org.RoleViewer, Slug: "nginx-memory"},
-							{Name: "Root Page (react)", Type: "page", Role: org.RoleViewer, Path: "/a/my-simple-app", DefaultNav: true, AddToNav: true, Slug: "root-page-react"},
+							{Name: "Nginx Memory", Path: "dashboards/memory.json", Type: "dashboard", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-memory"},
+							{Name: "Root Page (react)", Type: "page", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Path: "/a/my-simple-app", DefaultNav: true, AddToNav: true, Slug: "root-page-react"},
 						},
 						Backend: false,
 					},
@@ -439,7 +498,7 @@ func TestLoader_Load(t *testing.T) {
 		reg := fakes.NewFakePluginRegistry()
 		procPrvdr := fakes.NewFakeBackendProcessProvider()
 		procMgr := fakes.NewFakeProcessManager()
-		errTracker := pluginerrs.ProvideSignatureErrorTracker()
+		errTracker := pluginerrs.ProvideErrorTracker()
 		l := newLoader(t, tt.cfg, reg, procMgr, procPrvdr, errTracker)
 
 		t.Run(tt.name, func(t *testing.T) {
@@ -449,7 +508,7 @@ func TestLoader_Load(t *testing.T) {
 				t.Fatalf("Result mismatch (-want +got):\n%s", cmp.Diff(got, tt.want, compareOpts...))
 			}
 
-			pluginErrs := errTracker.SignatureErrors(context.Background())
+			pluginErrs := errTracker.Errors(context.Background())
 			require.Equal(t, len(tt.pluginErrors), len(pluginErrs))
 			for _, pluginErr := range pluginErrs {
 				require.Equal(t, tt.pluginErrors[pluginErr.PluginID], pluginErr)
@@ -461,8 +520,6 @@ func TestLoader_Load(t *testing.T) {
 }
 
 func TestLoader_Load_ExternalRegistration(t *testing.T) {
-	stringPtr := func(s string) *string { return &s }
-
 	t.Run("Load a plugin with service account registration", func(t *testing.T) {
 		cfg := &config.PluginManagementCfg{
 			PluginsAllowUnsigned: []string{"grafana-test-datasource"},
@@ -492,12 +549,21 @@ func TestLoader_Load_ExternalRegistration(t *testing.T) {
 					Dependencies: plugins.Dependencies{
 						GrafanaVersion: "*",
 						Plugins:        []plugins.Dependency{},
+						Extensions: plugins.ExtensionsDependencies{
+							ExposedComponents: []string{},
+						},
 					},
-					IAM: &pfs.IAM{
-						Permissions: []pfs.Permission{
+					Extensions: plugins.Extensions{
+						AddedLinks:        []plugins.AddedLink{},
+						AddedComponents:   []plugins.AddedComponent{},
+						ExposedComponents: []plugins.ExposedComponent{},
+						ExtensionPoints:   []plugins.ExtensionPoint{},
+					},
+					IAM: &auth.IAM{
+						Permissions: []auth.Permission{
 							{
 								Action: "read",
-								Scope:  stringPtr("datasource"),
+								Scope:  "datasource",
 							},
 						},
 					},
@@ -516,7 +582,7 @@ func TestLoader_Load_ExternalRegistration(t *testing.T) {
 
 		backendFactoryProvider := fakes.NewFakeBackendProcessProvider()
 		backendFactoryProvider.BackendFactoryFunc = func(ctx context.Context, plugin *plugins.Plugin) backendplugin.PluginFactoryFunc {
-			return func(pluginID string, logger log.Logger, env func() []string) (backendplugin.Plugin, error) {
+			return func(pluginID string, logger log.Logger, tracer trace.Tracer, env func() []string) (backendplugin.Plugin, error) {
 				require.Equal(t, "grafana-test-datasource", pluginID)
 				return &fakes.FakeBackendPlugin{}, nil
 			}
@@ -594,6 +660,15 @@ func TestLoader_Load_CustomSource(t *testing.T) {
 				Dependencies: plugins.Dependencies{
 					GrafanaVersion: "3.x.x",
 					Plugins:        []plugins.Dependency{},
+					Extensions: plugins.ExtensionsDependencies{
+						ExposedComponents: []string{},
+					},
+				},
+				Extensions: plugins.Extensions{
+					AddedLinks:        []plugins.AddedLink{},
+					AddedComponents:   []plugins.AddedComponent{},
+					ExposedComponents: []plugins.ExposedComponent{},
+					ExtensionPoints:   []plugins.ExtensionPoint{},
 				},
 			},
 			FS:        mustNewStaticFSForTests(t, filepath.Join(testDataDir(t), "cdn/plugin")),
@@ -603,7 +678,7 @@ func TestLoader_Load_CustomSource(t *testing.T) {
 			Module:    "https://cdn.example.com/grafana-worldmap-panel/0.3.3/public/plugins/grafana-worldmap-panel/module.js",
 		}}
 
-		l := newLoader(t, cfg, fakes.NewFakePluginRegistry(), fakes.NewFakeProcessManager(), fakes.NewFakeBackendProcessProvider(), newFakeSignatureErrorTracker())
+		l := newLoader(t, cfg, fakes.NewFakePluginRegistry(), fakes.NewFakeProcessManager(), fakes.NewFakeBackendProcessProvider(), newFakeErrorTracker())
 		got, err := l.Load(context.Background(), &fakes.FakePluginSource{
 			PluginClassFunc: func(ctx context.Context) plugins.Class {
 				return plugins.ClassBundled
@@ -633,7 +708,7 @@ func TestLoader_Load_MultiplePlugins(t *testing.T) {
 			pluginPaths     []string
 			existingPlugins map[string]struct{}
 			want            []*plugins.Plugin
-			pluginErrors    map[string]*plugins.SignatureError
+			pluginErrors    map[string]*plugins.Error
 		}{
 			{
 				name: "Load multiple plugins (broken, valid, unsigned)",
@@ -666,6 +741,15 @@ func TestLoader_Load_MultiplePlugins(t *testing.T) {
 							Dependencies: plugins.Dependencies{
 								GrafanaVersion: "*",
 								Plugins:        []plugins.Dependency{},
+								Extensions: plugins.ExtensionsDependencies{
+									ExposedComponents: []string{},
+								},
+							},
+							Extensions: plugins.Extensions{
+								AddedLinks:        []plugins.AddedLink{},
+								AddedComponents:   []plugins.AddedComponent{},
+								ExposedComponents: []plugins.ExposedComponent{},
+								ExtensionPoints:   []plugins.ExtensionPoint{},
 							},
 							Backend:    true,
 							Executable: "test",
@@ -680,7 +764,7 @@ func TestLoader_Load_MultiplePlugins(t *testing.T) {
 						SignatureOrg:  "Will Browne",
 					},
 				},
-				pluginErrors: map[string]*plugins.SignatureError{
+				pluginErrors: map[string]*plugins.Error{
 					"test-panel": {
 						PluginID:        "test-panel",
 						SignatureStatus: plugins.SignatureStatusUnsigned,
@@ -693,7 +777,7 @@ func TestLoader_Load_MultiplePlugins(t *testing.T) {
 			reg := fakes.NewFakePluginRegistry()
 			procPrvdr := fakes.NewFakeBackendProcessProvider()
 			procMgr := fakes.NewFakeProcessManager()
-			errTracker := pluginerrs.ProvideSignatureErrorTracker()
+			errTracker := pluginerrs.ProvideErrorTracker()
 
 			l := newLoader(t, tt.cfg, reg, procMgr, procPrvdr, errTracker)
 			t.Run(tt.name, func(t *testing.T) {
@@ -712,7 +796,7 @@ func TestLoader_Load_MultiplePlugins(t *testing.T) {
 				if !cmp.Equal(got, tt.want, compareOpts...) {
 					t.Fatalf("Result mismatch (-want +got):\n%s", cmp.Diff(got, tt.want, compareOpts...))
 				}
-				pluginErrs := errTracker.SignatureErrors(context.Background())
+				pluginErrs := errTracker.Errors(context.Background())
 				require.Equal(t, len(tt.pluginErrors), len(pluginErrs))
 				for _, pluginErr := range pluginErrs {
 					require.Equal(t, tt.pluginErrors[pluginErr.PluginID], pluginErr)
@@ -762,6 +846,15 @@ func TestLoader_Load_RBACReady(t *testing.T) {
 							GrafanaVersion:    "*",
 							GrafanaDependency: ">=8.0.0",
 							Plugins:           []plugins.Dependency{},
+							Extensions: plugins.ExtensionsDependencies{
+								ExposedComponents: []string{},
+							},
+						},
+						Extensions: plugins.Extensions{
+							AddedLinks:        []plugins.AddedLink{},
+							AddedComponents:   []plugins.AddedComponent{},
+							ExposedComponents: []plugins.ExposedComponent{},
+							ExtensionPoints:   []plugins.ExtensionPoint{},
 						},
 						Includes: []*plugins.Includes{},
 						Roles: []plugins.RoleRegistration{
@@ -796,7 +889,7 @@ func TestLoader_Load_RBACReady(t *testing.T) {
 		reg := fakes.NewFakePluginRegistry()
 		procPrvdr := fakes.NewFakeBackendProcessProvider()
 		procMgr := fakes.NewFakeProcessManager()
-		l := newLoader(t, tt.cfg, reg, procMgr, procPrvdr, newFakeSignatureErrorTracker())
+		l := newLoader(t, tt.cfg, reg, procMgr, procPrvdr, newFakeErrorTracker())
 
 		got, err := l.Load(context.Background(), &fakes.FakePluginSource{
 			PluginClassFunc: func(ctx context.Context) plugins.Class {
@@ -835,10 +928,18 @@ func TestLoader_Load_Signature_RootURL(t *testing.T) {
 						},
 						Version: "1.0.0",
 					},
-					State:        plugins.ReleaseStateAlpha,
-					Dependencies: plugins.Dependencies{GrafanaVersion: "*", Plugins: []plugins.Dependency{}},
-					Backend:      true,
-					Executable:   "test",
+					State: plugins.ReleaseStateAlpha,
+					Dependencies: plugins.Dependencies{GrafanaVersion: "*", Plugins: []plugins.Dependency{}, Extensions: plugins.ExtensionsDependencies{
+						ExposedComponents: []string{},
+					}},
+					Extensions: plugins.Extensions{
+						AddedLinks:        []plugins.AddedLink{},
+						AddedComponents:   []plugins.AddedComponent{},
+						ExposedComponents: []plugins.ExposedComponent{},
+						ExtensionPoints:   []plugins.ExtensionPoint{},
+					},
+					Backend:    true,
+					Executable: "test",
 				},
 				FS:            mustNewStaticFSForTests(t, filepath.Join(testDataDir(t), "valid-v2-pvt-signature-root-url-uri/plugin")),
 				Class:         plugins.ClassExternal,
@@ -854,7 +955,7 @@ func TestLoader_Load_Signature_RootURL(t *testing.T) {
 		procPrvdr := fakes.NewFakeBackendProcessProvider()
 		procMgr := fakes.NewFakeProcessManager()
 		cfg := &config.PluginManagementCfg{GrafanaAppURL: defaultAppURL}
-		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeSignatureErrorTracker())
+		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeErrorTracker())
 		got, err := l.Load(context.Background(), &fakes.FakePluginSource{
 			PluginClassFunc: func(ctx context.Context) plugins.Class {
 				return plugins.ClassExternal
@@ -908,12 +1009,21 @@ func TestLoader_Load_DuplicatePlugins(t *testing.T) {
 							{Type: "datasource", ID: "graphite", Name: "Graphite", Version: "1.0.0"},
 							{Type: "panel", ID: "graph", Name: "Graph", Version: "1.0.0"},
 						},
+						Extensions: plugins.ExtensionsDependencies{
+							ExposedComponents: []string{},
+						},
+					},
+					Extensions: plugins.Extensions{
+						AddedLinks:        []plugins.AddedLink{},
+						AddedComponents:   []plugins.AddedComponent{},
+						ExposedComponents: []plugins.ExposedComponent{},
+						ExtensionPoints:   []plugins.ExtensionPoint{},
 					},
 					Includes: []*plugins.Includes{
-						{Name: "Nginx Connections", Path: "dashboards/connections.json", Type: "dashboard", Role: org.RoleViewer, Slug: "nginx-connections"},
-						{Name: "Nginx Memory", Path: "dashboards/memory.json", Type: "dashboard", Role: org.RoleViewer, Slug: "nginx-memory"},
-						{Name: "Nginx Panel", Type: "panel", Role: org.RoleViewer, Slug: "nginx-panel"},
-						{Name: "Nginx Datasource", Type: "datasource", Role: org.RoleViewer, Slug: "nginx-datasource"},
+						{Name: "Nginx Connections", Path: "dashboards/connections.json", Type: "dashboard", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-connections"},
+						{Name: "Nginx Memory", Path: "dashboards/memory.json", Type: "dashboard", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-memory"},
+						{Name: "Nginx Panel", Type: "panel", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-panel"},
+						{Name: "Nginx Datasource", Type: "datasource", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-datasource"},
 					},
 					Backend: false,
 				},
@@ -931,7 +1041,7 @@ func TestLoader_Load_DuplicatePlugins(t *testing.T) {
 		procPrvdr := fakes.NewFakeBackendProcessProvider()
 		procMgr := fakes.NewFakeProcessManager()
 		cfg := &config.PluginManagementCfg{}
-		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeSignatureErrorTracker())
+		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeErrorTracker())
 		got, err := l.Load(context.Background(), &fakes.FakePluginSource{
 			PluginClassFunc: func(ctx context.Context) plugins.Class {
 				return plugins.ClassExternal
@@ -989,12 +1099,21 @@ func TestLoader_Load_SkipUninitializedPlugins(t *testing.T) {
 							{Type: "datasource", ID: "graphite", Name: "Graphite", Version: "1.0.0"},
 							{Type: "panel", ID: "graph", Name: "Graph", Version: "1.0.0"},
 						},
+						Extensions: plugins.ExtensionsDependencies{
+							ExposedComponents: []string{},
+						},
 					},
 					Includes: []*plugins.Includes{
-						{Name: "Nginx Connections", Path: "dashboards/connections.json", Type: "dashboard", Role: org.RoleViewer, Slug: "nginx-connections"},
-						{Name: "Nginx Memory", Path: "dashboards/memory.json", Type: "dashboard", Role: org.RoleViewer, Slug: "nginx-memory"},
-						{Name: "Nginx Panel", Type: "panel", Role: org.RoleViewer, Slug: "nginx-panel"},
-						{Name: "Nginx Datasource", Type: "datasource", Role: org.RoleViewer, Slug: "nginx-datasource"},
+						{Name: "Nginx Connections", Path: "dashboards/connections.json", Type: "dashboard", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-connections"},
+						{Name: "Nginx Memory", Path: "dashboards/memory.json", Type: "dashboard", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-memory"},
+						{Name: "Nginx Panel", Type: "panel", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-panel"},
+						{Name: "Nginx Datasource", Type: "datasource", Role: org.RoleViewer, Action: plugins.ActionAppAccess, Slug: "nginx-datasource"},
+					},
+					Extensions: plugins.Extensions{
+						AddedLinks:        []plugins.AddedLink{},
+						AddedComponents:   []plugins.AddedComponent{},
+						ExposedComponents: []plugins.ExposedComponent{},
+						ExtensionPoints:   []plugins.ExtensionPoint{},
 					},
 					Backend: false,
 				},
@@ -1012,7 +1131,7 @@ func TestLoader_Load_SkipUninitializedPlugins(t *testing.T) {
 		procPrvdr := fakes.NewFakeBackendProcessProvider()
 		// Cause an initialization error
 		procPrvdr.BackendFactoryFunc = func(ctx context.Context, p *plugins.Plugin) backendplugin.PluginFactoryFunc {
-			return func(pluginID string, _ log.Logger, _ func() []string) (backendplugin.Plugin, error) {
+			return func(pluginID string, _ log.Logger, _ trace.Tracer, _ func() []string) (backendplugin.Plugin, error) {
 				if pluginID == "test-datasource" {
 					return nil, errors.New("failed to initialize")
 				}
@@ -1021,7 +1140,7 @@ func TestLoader_Load_SkipUninitializedPlugins(t *testing.T) {
 		}
 		procMgr := fakes.NewFakeProcessManager()
 		cfg := &config.PluginManagementCfg{}
-		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeSignatureErrorTracker())
+		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeErrorTracker())
 		got, err := l.Load(context.Background(), &fakes.FakePluginSource{
 			PluginClassFunc: func(ctx context.Context) plugins.Class {
 				return plugins.ClassExternal
@@ -1203,6 +1322,15 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 			Dependencies: plugins.Dependencies{
 				GrafanaVersion: "*",
 				Plugins:        []plugins.Dependency{},
+				Extensions: plugins.ExtensionsDependencies{
+					ExposedComponents: []string{},
+				},
+			},
+			Extensions: plugins.Extensions{
+				AddedLinks:        []plugins.AddedLink{},
+				AddedComponents:   []plugins.AddedComponent{},
+				ExposedComponents: []plugins.ExposedComponent{},
+				ExtensionPoints:   []plugins.ExtensionPoint{},
 			},
 			Backend: true,
 		},
@@ -1236,10 +1364,19 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 			Dependencies: plugins.Dependencies{
 				GrafanaVersion: "*",
 				Plugins:        []plugins.Dependency{},
+				Extensions: plugins.ExtensionsDependencies{
+					ExposedComponents: []string{},
+				},
+			},
+			Extensions: plugins.Extensions{
+				AddedLinks:        []plugins.AddedLink{},
+				AddedComponents:   []plugins.AddedComponent{},
+				ExposedComponents: []plugins.ExposedComponent{},
+				ExtensionPoints:   []plugins.ExtensionPoint{},
 			},
 		},
-		Module:        "public/plugins/test-panel/module.js",
-		BaseURL:       "public/plugins/test-panel",
+		Module:        "public/plugins/test-datasource/nested/module.js",
+		BaseURL:       "public/plugins/test-datasource/nested",
 		FS:            mustNewStaticFSForTests(t, filepath.Join(testDataDir(t), "nested-plugins/parent/nested")),
 		Signature:     plugins.SignatureStatusValid,
 		SignatureType: plugins.SignatureTypeGrafana,
@@ -1255,7 +1392,7 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 		procMgr := fakes.NewFakeProcessManager()
 		reg := fakes.NewFakePluginRegistry()
 		cfg := &config.PluginManagementCfg{}
-		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeSignatureErrorTracker())
+		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeErrorTracker())
 
 		got, err := l.Load(context.Background(), &fakes.FakePluginSource{
 			PluginClassFunc: func(ctx context.Context) plugins.Class {
@@ -1331,6 +1468,9 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 					GrafanaVersion:    "7.0.0",
 					GrafanaDependency: ">=7.0.0",
 					Plugins:           []plugins.Dependency{},
+					Extensions: plugins.ExtensionsDependencies{
+						ExposedComponents: []string{},
+					},
 				},
 				Includes: []*plugins.Includes{
 					{
@@ -1338,6 +1478,7 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 						Path:       "/a/myorgid-simple-app",
 						Type:       "page",
 						Role:       org.RoleViewer,
+						Action:     plugins.ActionAppAccess,
 						AddToNav:   true,
 						DefaultNav: true,
 						Slug:       "root-page-react",
@@ -1347,6 +1488,7 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 						Path:     "/a/myorgid-simple-app/?tab=b",
 						Type:     "page",
 						Role:     org.RoleViewer,
+						Action:   plugins.ActionAppAccess,
 						AddToNav: true,
 						Slug:     "root-page-tab-b",
 					},
@@ -1359,20 +1501,28 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 						Slug:     "react-config",
 					},
 					{
-						Name: "Streaming Example",
-						Path: "dashboards/streaming.json",
-						Type: "dashboard",
-						Role: org.RoleViewer,
-						Slug: "streaming-example",
+						Name:   "Streaming Example",
+						Path:   "dashboards/streaming.json",
+						Type:   "dashboard",
+						Role:   org.RoleViewer,
+						Action: plugins.ActionAppAccess,
+						Slug:   "streaming-example",
 					},
 					{
-						Name: "Lots of Stats",
-						Path: "dashboards/stats.json",
-						Type: "dashboard",
-						Role: org.RoleViewer,
-						Slug: "lots-of-stats",
+						Name:   "Lots of Stats",
+						Path:   "dashboards/stats.json",
+						Type:   "dashboard",
+						Role:   org.RoleViewer,
+						Action: plugins.ActionAppAccess,
+						Slug:   "lots-of-stats",
 					},
 				},
+				Extensions: plugins.Extensions{
+					AddedLinks:        []plugins.AddedLink{},
+					AddedComponents:   []plugins.AddedComponent{},
+					ExposedComponents: []plugins.ExposedComponent{},
+					ExtensionPoints:   []plugins.ExtensionPoint{},
+				},
 				Backend: false,
 			},
 			Module:        "public/plugins/myorgid-simple-app/module.js",
@@ -1399,8 +1549,8 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 						{Name: "License", URL: "https://github.com/grafana/grafana-starter-panel/blob/master/LICENSE"},
 					},
 					Logos: plugins.Logos{
-						Small: "public/plugins/myorgid-simple-panel/img/logo.svg",
-						Large: "public/plugins/myorgid-simple-panel/img/logo.svg",
+						Small: "public/plugins/myorgid-simple-app/child/img/logo.svg",
+						Large: "public/plugins/myorgid-simple-app/child/img/logo.svg",
 					},
 					Screenshots: []plugins.Screenshots{},
 					Description: "Grafana Panel Plugin Template",
@@ -1412,10 +1562,19 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 					GrafanaDependency: ">=7.0.0",
 					GrafanaVersion:    "*",
 					Plugins:           []plugins.Dependency{},
+					Extensions: plugins.ExtensionsDependencies{
+						ExposedComponents: []string{},
+					},
+				},
+				Extensions: plugins.Extensions{
+					AddedLinks:        []plugins.AddedLink{},
+					AddedComponents:   []plugins.AddedComponent{},
+					ExposedComponents: []plugins.ExposedComponent{},
+					ExtensionPoints:   []plugins.ExtensionPoint{},
 				},
 			},
 			Module:          "public/plugins/myorgid-simple-app/child/module.js",
-			BaseURL:         "public/plugins/myorgid-simple-app",
+			BaseURL:         "public/plugins/myorgid-simple-app/child",
 			FS:              mustNewStaticFSForTests(t, filepath.Join(testDataDir(t), "app-with-child/dist/child")),
 			IncludedInAppID: parent.ID,
 			Signature:       plugins.SignatureStatusValid,
@@ -1432,7 +1591,7 @@ func TestLoader_Load_NestedPlugins(t *testing.T) {
 		procPrvdr := fakes.NewFakeBackendProcessProvider()
 		procMgr := fakes.NewFakeProcessManager()
 		cfg := &config.PluginManagementCfg{}
-		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeSignatureErrorTracker())
+		l := newLoader(t, cfg, reg, procMgr, procPrvdr, newFakeErrorTracker())
 		got, err := l.Load(context.Background(), &fakes.FakePluginSource{
 			PluginClassFunc: func(ctx context.Context) plugins.Class {
 				return plugins.ClassExternal
@@ -1463,7 +1622,7 @@ type loaderDepOpts struct {
 }
 
 func newLoader(t *testing.T, cfg *config.PluginManagementCfg, reg registry.Service, proc process.Manager,
-	backendFactory plugins.BackendFactoryProvider, sigErrTracker pluginerrs.SignatureErrorTracker,
+	backendFactory plugins.BackendFactoryProvider, errTracker pluginerrs.ErrorTracker,
 ) *Loader {
 	assets := assetpath.ProvideService(cfg, pluginscdn.ProvideService(cfg))
 	angularInspector := angularinspector.NewStaticInspector()
@@ -1474,9 +1633,9 @@ func newLoader(t *testing.T, cfg *config.PluginManagementCfg, reg registry.Servi
 	return ProvideService(pipeline.ProvideDiscoveryStage(cfg,
 		finder.NewLocalFinder(false), reg),
 		pipeline.ProvideBootstrapStage(cfg, signature.DefaultCalculator(cfg), assets),
-		pipeline.ProvideValidationStage(cfg, signature.NewValidator(signature.NewUnsignedAuthorizer(cfg)), angularInspector, sigErrTracker),
-		pipeline.ProvideInitializationStage(cfg, reg, backendFactory, proc, &fakes.FakeAuthService{}, fakes.NewFakeRoleRegistry(), fakes.NewFakePluginEnvProvider(), tracing.InitializeTracerForTest()),
-		terminate)
+		pipeline.ProvideValidationStage(cfg, signature.NewValidator(signature.NewUnsignedAuthorizer(cfg)), angularInspector),
+		pipeline.ProvideInitializationStage(cfg, reg, backendFactory, proc, &fakes.FakeAuthService{}, fakes.NewFakeRoleRegistry(), fakes.NewFakeActionSetRegistry(), fakes.NewFakePluginEnvProvider(), tracing.InitializeTracerForTest()),
+		terminate, errTracker)
 }
 
 func newLoaderWithOpts(t *testing.T, cfg *config.PluginManagementCfg, opts loaderDepOpts) *Loader {
@@ -1486,7 +1645,7 @@ func newLoaderWithOpts(t *testing.T, cfg *config.PluginManagementCfg, opts loade
 
 	terminate, err := pipeline.ProvideTerminationStage(cfg, reg, proc)
 	require.NoError(t, err)
-	sigErrTracker := pluginerrs.ProvideSignatureErrorTracker()
+	errTracker := pluginerrs.ProvideErrorTracker()
 
 	angularInspector := opts.angularInspector
 	if opts.angularInspector == nil {
@@ -1506,9 +1665,9 @@ func newLoaderWithOpts(t *testing.T, cfg *config.PluginManagementCfg, opts loade
 	return ProvideService(pipeline.ProvideDiscoveryStage(cfg,
 		finder.NewLocalFinder(false), reg),
 		pipeline.ProvideBootstrapStage(cfg, signature.DefaultCalculator(cfg), assets),
-		pipeline.ProvideValidationStage(cfg, signature.NewValidator(signature.NewUnsignedAuthorizer(cfg)), angularInspector, sigErrTracker),
-		pipeline.ProvideInitializationStage(cfg, reg, backendFactoryProvider, proc, authServiceRegistry, fakes.NewFakeRoleRegistry(), fakes.NewFakePluginEnvProvider(), tracing.InitializeTracerForTest()),
-		terminate)
+		pipeline.ProvideValidationStage(cfg, signature.NewValidator(signature.NewUnsignedAuthorizer(cfg)), angularInspector),
+		pipeline.ProvideInitializationStage(cfg, reg, backendFactoryProvider, proc, authServiceRegistry, fakes.NewFakeRoleRegistry(), fakes.NewFakeActionSetRegistry(), fakes.NewFakePluginEnvProvider(), tracing.InitializeTracerForTest()),
+		terminate, errTracker)
 }
 
 func verifyState(t *testing.T, ps []*plugins.Plugin, reg registry.Service,
