@@ -1,11 +1,9 @@
 package user
 
 import (
-	"fmt"
-	"strings"
 	"time"
 
-	"github.com/grafana/grafana/pkg/services/auth/identity"
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/services/search/model"
 )
 
@@ -39,7 +37,7 @@ type User struct {
 	Company       string
 	EmailVerified bool
 	Theme         string
-	HelpFlags1    HelpFlags1
+	HelpFlags1    HelpFlags1 `xorm:"help_flags1"`
 	IsDisabled    bool
 
 	IsAdmin          bool
@@ -82,15 +80,17 @@ type UpdateUserCommand struct {
 	Login string `json:"login"`
 	Theme string `json:"theme"`
 
-	UserID        int64 `json:"-"`
-	EmailVerified *bool `json:"-"`
-}
-
-type ChangeUserPasswordCommand struct {
-	OldPassword Password `json:"oldPassword"`
-	NewPassword Password `json:"newPassword"`
-
-	UserID int64 `json:"-"`
+	UserID         int64 `json:"-"`
+	IsDisabled     *bool `json:"-"`
+	EmailVerified  *bool `json:"-"`
+	IsGrafanaAdmin *bool `json:"-"`
+	// If password is included it will be validated, hashed and updated for user.
+	Password *Password `json:"-"`
+	// If old password is included it will be validated against users current password.
+	OldPassword *Password `json:"-"`
+	// If OrgID is included update current org for user
+	OrgID      *int64      `json:"-"`
+	HelpFlags1 *HelpFlags1 `json:"-"`
 }
 
 type UpdateUserLastSeenAtCommand struct {
@@ -98,9 +98,10 @@ type UpdateUserLastSeenAtCommand struct {
 	OrgID  int64
 }
 
-type SetUsingOrgCommand struct {
-	UserID int64
-	OrgID  int64
+type ListUserResult struct {
+	Users      []*User
+	ContinueID int64
+	RV         int64
 }
 
 type SearchUsersQuery struct {
@@ -125,7 +126,7 @@ type SearchUserQueryResult struct {
 
 type UserSearchHitDTO struct {
 	ID            int64                `json:"id" xorm:"id"`
-	UID           string               `json:"uid" xorm:"id"`
+	UID           string               `json:"uid" xorm:"uid"`
 	Name          string               `json:"name"`
 	Login         string               `json:"login"`
 	Email         string               `json:"email"`
@@ -176,21 +177,11 @@ func (auth *AuthModuleConversion) ToDB() ([]byte, error) {
 	return []byte{}, nil
 }
 
-type DisableUserCommand struct {
-	UserID     int64 `xorm:"user_id"`
-	IsDisabled bool
-}
-
 type BatchDisableUsersCommand struct {
 	UserIDs    []int64 `xorm:"user_ids"`
 	IsDisabled bool
 }
 
-type SetUserHelpFlagCommand struct {
-	HelpFlags1 HelpFlags1
-	UserID     int64 `xorm:"user_id"`
-}
-
 type GetSignedInUserQuery struct {
 	UserID int64 `xorm:"user_id"`
 	Login  string
@@ -221,6 +212,10 @@ type GetUserByIDQuery struct {
 	ID int64
 }
 
+type GetUserByUIDQuery struct {
+	UID string
+}
+
 type StartVerifyEmailCommand struct {
 	User   User
 	Email  string
@@ -228,38 +223,10 @@ type StartVerifyEmailCommand struct {
 }
 
 type CompleteEmailVerifyCommand struct {
+	User identity.Requester
 	Code string
 }
 
-type ErrCaseInsensitiveLoginConflict struct {
-	Users []User
-}
-
-type UserDisplayDTO struct {
-	ID        int64  `json:"id,omitempty"`
-	UID       string `json:"uid,omitempty"`
-	Name      string `json:"name,omitempty"`
-	Login     string `json:"login,omitempty"`
-	AvatarURL string `json:"avatarUrl"`
-}
-
-func (e *ErrCaseInsensitiveLoginConflict) Unwrap() error {
-	return ErrCaseInsensitive
-}
-
-func (e *ErrCaseInsensitiveLoginConflict) Error() string {
-	n := len(e.Users)
-
-	userStrings := make([]string, 0, n)
-	for _, v := range e.Users {
-		userStrings = append(userStrings, fmt.Sprintf("%s (email:%s, id:%d)", v.Login, v.Email, v.ID))
-	}
-
-	return fmt.Sprintf(
-		"Found a conflict in user login information. %d users already exist with either the same login or email: [%s].",
-		n, strings.Join(userStrings, ", "))
-}
-
 type Filter interface {
 	WhereCondition() *WhereCondition
 	InCondition() *InCondition
@@ -296,5 +263,11 @@ const (
 
 type AdminCreateUserResponse struct {
 	ID      int64  `json:"id"`
+	UID     string `json:"uid"`
 	Message string `json:"message"`
 }
+
+type ChangeUserPasswordCommand struct {
+	OldPassword Password `json:"oldPassword"`
+	NewPassword Password `json:"newPassword"`
+}
