@@ -1,7 +1,7 @@
 package buffered
 
 import (
-	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"strings"
@@ -9,6 +9,8 @@ import (
 
 	"github.com/grafana/grafana-plugin-sdk-go/backend"
 	"github.com/grafana/grafana-plugin-sdk-go/data"
+	"github.com/influxdata/influxql"
+	jsoniter "github.com/json-iterator/go"
 
 	"github.com/grafana/grafana/pkg/tsdb/influxdb/influxql/util"
 	"github.com/grafana/grafana/pkg/tsdb/influxdb/models"
@@ -24,7 +26,11 @@ func parse(buf io.Reader, statusCode int, query *models.Query) *backend.DataResp
 	response, jsonErr := parseJSON(buf)
 
 	if statusCode/100 != 2 {
-		return &backend.DataResponse{Error: fmt.Errorf("InfluxDB returned error: %s", response.Error)}
+		errorStr := response.Error
+		if errorStr == "" {
+			errorStr = response.Message
+		}
+		return &backend.DataResponse{Error: fmt.Errorf("InfluxDB returned error: %s", errorStr)}
 	}
 
 	if jsonErr != nil {
@@ -32,12 +38,12 @@ func parse(buf io.Reader, statusCode int, query *models.Query) *backend.DataResp
 	}
 
 	if response.Error != "" {
-		return &backend.DataResponse{Error: fmt.Errorf(response.Error)}
+		return &backend.DataResponse{Error: errors.New(response.Error)}
 	}
 
 	result := response.Results[0]
 	if result.Error != "" {
-		return &backend.DataResponse{Error: fmt.Errorf(result.Error)}
+		return &backend.DataResponse{Error: errors.New(result.Error)}
 	}
 
 	if query.ResultFormat == "table" {
@@ -50,8 +56,9 @@ func parse(buf io.Reader, statusCode int, query *models.Query) *backend.DataResp
 func parseJSON(buf io.Reader) (models.Response, error) {
 	var response models.Response
 
+	json := jsoniter.ConfigCompatibleWithStandardLibrary
+
 	dec := json.NewDecoder(buf)
-	dec.UseNumber()
 
 	err := dec.Decode(&response)
 
@@ -154,6 +161,12 @@ func newValueFields(rows []models.Row, labels data.Labels, colIdxStart, colIdxEn
 				case "json.Number":
 					value := util.ParseNumber(valuePair[colIdx])
 					floatArray = append(floatArray, value)
+				case "float64":
+					if value, ok := valuePair[colIdx].(float64); ok {
+						floatArray = append(floatArray, &value)
+					} else {
+						floatArray = append(floatArray, nil)
+					}
 				case "bool":
 					value, ok := valuePair[colIdx].(bool)
 					if ok {
@@ -196,6 +209,8 @@ func newValueFields(rows []models.Row, labels data.Labels, colIdxStart, colIdxEn
 				valueField = data.NewField(row.Columns[colIdx], labels, stringArray)
 			case "json.Number":
 				valueField = data.NewField(row.Columns[colIdx], labels, floatArray)
+			case "float64":
+				valueField = data.NewField(row.Columns[colIdx], labels, floatArray)
 			case "bool":
 				valueField = data.NewField(row.Columns[colIdx], labels, boolArray)
 			case "null":
@@ -241,12 +256,6 @@ func transformRowsForTimeSeries(rows []models.Row, query models.Query) data.Fram
 
 		if !hasTimeCol {
 			newFrame := newFrameWithoutTimeField(row, query)
-			if len(frames) == 0 {
-				newFrame.Meta = &data.FrameMeta{
-					ExecutedQueryString:    query.RawQuery,
-					PreferredVisualization: util.GetVisType(query.ResultFormat),
-				}
-			}
 			frames = append(frames, newFrame)
 		} else {
 			for colIndex, column := range row.Columns {
@@ -254,27 +263,28 @@ func transformRowsForTimeSeries(rows []models.Row, query models.Query) data.Fram
 					continue
 				}
 				newFrame := newFrameWithTimeField(row, column, colIndex, query, frameName)
-				if len(frames) == 0 {
-					newFrame.Meta = &data.FrameMeta{
-						ExecutedQueryString:    query.RawQuery,
-						PreferredVisualization: util.GetVisType(query.ResultFormat),
-					}
-				}
 				frames = append(frames, newFrame)
 			}
 		}
 	}
 
+	if len(frames) > 0 {
+		frames[0].Meta = &data.FrameMeta{
+			ExecutedQueryString:    query.RawQuery,
+			PreferredVisualization: util.GetVisType(query.ResultFormat),
+		}
+	}
+
 	return frames
 }
 
 func newFrameWithTimeField(row models.Row, column string, colIndex int, query models.Query, frameName []byte) *data.Frame {
-	var timeArray []time.Time
 	var floatArray []*float64
 	var stringArray []*string
 	var boolArray []*bool
 	valType := util.Typeof(row.Values, colIndex)
 
+	timeArray := make([]time.Time, 0, len(row.Values))
 	for _, valuePair := range row.Values {
 		timestamp, timestampErr := util.ParseTimestamp(valuePair[0])
 		// we only add this row if the timestamp is valid
@@ -294,6 +304,12 @@ func newFrameWithTimeField(row models.Row, column string, colIndex int, query mo
 		case "json.Number":
 			value := util.ParseNumber(valuePair[colIndex])
 			floatArray = append(floatArray, value)
+		case "float64":
+			if value, ok := valuePair[colIndex].(float64); ok {
+				floatArray = append(floatArray, &value)
+			} else {
+				floatArray = append(floatArray, nil)
+			}
 		case "bool":
 			value, ok := valuePair[colIndex].(bool)
 			if ok {
@@ -315,6 +331,8 @@ func newFrameWithTimeField(row models.Row, column string, colIndex int, query mo
 		valueField = data.NewField("Value", row.Tags, stringArray)
 	case "json.Number":
 		valueField = data.NewField("Value", row.Tags, floatArray)
+	case "float64":
+		valueField = data.NewField("Value", row.Tags, floatArray)
 	case "bool":
 		valueField = data.NewField("Value", row.Tags, boolArray)
 	case "null":
@@ -329,23 +347,38 @@ func newFrameWithTimeField(row models.Row, column string, colIndex int, query mo
 func newFrameWithoutTimeField(row models.Row, query models.Query) *data.Frame {
 	var values []*string
 
-	for _, valuePair := range row.Values {
-		if strings.Contains(strings.ToLower(query.RawQuery), strings.ToLower("CARDINALITY")) {
-			values = append(values, util.ParseString(valuePair[0]))
-		} else {
-			if strings.Contains(strings.ToLower(query.RawQuery), strings.ToLower("SHOW TAG VALUES")) {
-				if len(valuePair) >= 2 {
-					values = append(values, util.ParseString(valuePair[1]))
-				}
-			} else if strings.Contains(strings.ToLower(query.RawQuery), strings.ToLower("SHOW DIAGNOSTICS")) {
-				// https://docs.influxdata.com/platform/monitoring/influxdata-platform/tools/show-diagnostics/
-				for _, vp := range valuePair {
-					values = append(values, util.ParseString(vp))
-				}
-			} else {
-				if len(valuePair) >= 1 {
-					values = append(values, util.ParseString(valuePair[0]))
-				}
+	switch query.Statement.(type) {
+	case *influxql.ShowMeasurementCardinalityStatement,
+		*influxql.ShowSeriesCardinalityStatement,
+		*influxql.ShowFieldKeyCardinalityStatement,
+		*influxql.ShowTagValuesCardinalityStatement,
+		*influxql.ShowTagKeyCardinalityStatement:
+		// Handle all CARDINALITY queries
+		for _, valuePair := range row.Values {
+			if len(valuePair) >= 1 {
+				values = append(values, util.ParseString(valuePair[0]))
+			}
+		}
+	case *influxql.ShowDiagnosticsStatement:
+		// Handle SHOW DIAGNOSTICS
+		// https://docs.influxdata.com/platform/monitoring/influxdata-platform/tools/show-diagnostics/
+		for _, valuePair := range row.Values {
+			for _, vp := range valuePair {
+				values = append(values, util.ParseString(vp))
+			}
+		}
+	case *influxql.ShowTagValuesStatement:
+		// Handle SHOW TAG VALUES (non-CARDINALITY)
+		for _, valuePair := range row.Values {
+			if len(valuePair) >= 2 {
+				values = append(values, util.ParseString(valuePair[1]))
+			}
+		}
+	default:
+		// Handle other queries
+		for _, valuePair := range row.Values {
+			if len(valuePair) >= 1 {
+				values = append(values, util.ParseString(valuePair[0]))
 			}
 		}
 	}
