@@ -20,7 +20,7 @@ import (
 var ErrNoElementsOnSlice = errors.New("no element on slice when insert")
 
 // Insert insert one or more beans
-func (session *Session) Insert(beans ...interface{}) (int64, error) {
+func (session *Session) Insert(beans ...any) (int64, error) {
 	var affected int64
 	var err error
 
@@ -36,13 +36,13 @@ func (session *Session) Insert(beans ...interface{}) (int64, error) {
 
 	for _, bean := range beans {
 		switch bean := bean.(type) {
-		case map[string]interface{}:
+		case map[string]any:
 			cnt, err := session.insertMapInterface(bean)
 			if err != nil {
 				return affected, err
 			}
 			affected += cnt
-		case []map[string]interface{}:
+		case []map[string]any:
 			for i := 0; i < len(bean); i++ {
 				cnt, err := session.insertMapInterface(bean[i])
 				if err != nil {
@@ -100,7 +100,7 @@ func (session *Session) Insert(beans ...interface{}) (int64, error) {
 	return affected, err
 }
 
-func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error) {
+func (session *Session) innerInsertMulti(rowsSlicePtr any) (int64, error) {
 	sliceValue := reflect.Indirect(reflect.ValueOf(rowsSlicePtr))
 	if sliceValue.Kind() != reflect.Slice {
 		return 0, errors.New("needs a pointer to a slice")
@@ -124,7 +124,7 @@ func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error
 
 	var colNames []string
 	var colMultiPlaces []string
-	var args []interface{}
+	var args []any
 	var cols []*core.Column
 
 	for i := 0; i < size; i++ {
@@ -139,7 +139,7 @@ func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error
 			closure(elemValue)
 		}
 
-		if processor, ok := interface{}(elemValue).(BeforeInsertProcessor); ok {
+		if processor, ok := any(elemValue).(BeforeInsertProcessor); ok {
 			processor.BeforeInsert()
 		}
 
@@ -170,14 +170,14 @@ func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error
 					args = append(args, val)
 
 					var colName = col.Name
-					session.afterClosures = append(session.afterClosures, func(bean interface{}) {
+					session.afterClosures = append(session.afterClosures, func(bean any) {
 						col := table.GetColumn(colName)
 						setColumnTime(bean, col, t)
 					})
 				} else if col.IsVersion && session.statement.checkVersion {
 					args = append(args, 1)
 					var colName = col.Name
-					session.afterClosures = append(session.afterClosures, func(bean interface{}) {
+					session.afterClosures = append(session.afterClosures, func(bean any) {
 						col := table.GetColumn(colName)
 						setColumnInt(bean, col, 1)
 					})
@@ -221,14 +221,14 @@ func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error
 					args = append(args, val)
 
 					var colName = col.Name
-					session.afterClosures = append(session.afterClosures, func(bean interface{}) {
+					session.afterClosures = append(session.afterClosures, func(bean any) {
 						col := table.GetColumn(colName)
 						setColumnTime(bean, col, t)
 					})
 				} else if col.IsVersion && session.statement.checkVersion {
 					args = append(args, 1)
 					var colName = col.Name
-					session.afterClosures = append(session.afterClosures, func(bean interface{}) {
+					session.afterClosures = append(session.afterClosures, func(bean any) {
 						col := table.GetColumn(colName)
 						setColumnInt(bean, col, 1)
 					})
@@ -277,7 +277,7 @@ func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error
 			for _, closure := range session.afterClosures {
 				closure(elemValue)
 			}
-			if processor, ok := interface{}(elemValue).(AfterInsertProcessor); ok {
+			if processor, ok := any(elemValue).(AfterInsertProcessor); ok {
 				processor.AfterInsert()
 			}
 		} else {
@@ -285,12 +285,12 @@ func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error
 				if value, has := session.afterInsertBeans[elemValue]; has && value != nil {
 					*value = append(*value, session.afterClosures...)
 				} else {
-					afterClosures := make([]func(interface{}), lenAfterClosures)
+					afterClosures := make([]func(any), lenAfterClosures)
 					copy(afterClosures, session.afterClosures)
 					session.afterInsertBeans[elemValue] = &afterClosures
 				}
 			} else {
-				if _, ok := interface{}(elemValue).(AfterInsertProcessor); ok {
+				if _, ok := any(elemValue).(AfterInsertProcessor); ok {
 					session.afterInsertBeans[elemValue] = nil
 				}
 			}
@@ -302,7 +302,7 @@ func (session *Session) innerInsertMulti(rowsSlicePtr interface{}) (int64, error
 }
 
 // InsertMulti insert multiple records
-func (session *Session) InsertMulti(rowsSlicePtr interface{}) (int64, error) {
+func (session *Session) InsertMulti(rowsSlicePtr any) (int64, error) {
 	if session.isAutoClose {
 		defer session.Close()
 	}
@@ -320,7 +320,7 @@ func (session *Session) InsertMulti(rowsSlicePtr interface{}) (int64, error) {
 	return session.innerInsertMulti(rowsSlicePtr)
 }
 
-func (session *Session) innerInsert(bean interface{}) (int64, error) {
+func (session *Session) innerInsert(bean any) (int64, error) {
 	if err := session.statement.setRefBean(bean); err != nil {
 		return 0, err
 	}
@@ -336,7 +336,7 @@ func (session *Session) innerInsert(bean interface{}) (int64, error) {
 	}
 	cleanupProcessorsClosures(&session.beforeClosures) // cleanup after used
 
-	if processor, ok := interface{}(bean).(BeforeInsertProcessor); ok {
+	if processor, ok := any(bean).(BeforeInsertProcessor); ok {
 		processor.BeforeInsert()
 	}
 
@@ -431,12 +431,12 @@ func (session *Session) innerInsert(bean interface{}) (int64, error) {
 	sqlStr := buf.String()
 	args = buf.Args()
 
-	handleAfterInsertProcessorFunc := func(bean interface{}) {
+	handleAfterInsertProcessorFunc := func(bean any) {
 		if session.isAutoCommit {
 			for _, closure := range session.afterClosures {
 				closure(bean)
 			}
-			if processor, ok := interface{}(bean).(AfterInsertProcessor); ok {
+			if processor, ok := any(bean).(AfterInsertProcessor); ok {
 				processor.AfterInsert()
 			}
 		} else {
@@ -445,13 +445,13 @@ func (session *Session) innerInsert(bean interface{}) (int64, error) {
 				if value, has := session.afterInsertBeans[bean]; has && value != nil {
 					*value = append(*value, session.afterClosures...)
 				} else {
-					afterClosures := make([]func(interface{}), lenAfterClosures)
+					afterClosures := make([]func(any), lenAfterClosures)
 					copy(afterClosures, session.afterClosures)
 					session.afterInsertBeans[bean] = &afterClosures
 				}
 
 			} else {
-				if _, ok := interface{}(bean).(AfterInsertProcessor); ok {
+				if _, ok := any(bean).(AfterInsertProcessor); ok {
 					session.afterInsertBeans[bean] = nil
 				}
 			}
@@ -584,7 +584,7 @@ func (session *Session) innerInsert(bean interface{}) (int64, error) {
 // InsertOne insert only one struct into database as a record.
 // The in parameter bean must a struct or a point to struct. The return
 // parameter is inserted and error
-func (session *Session) InsertOne(bean interface{}) (int64, error) {
+func (session *Session) InsertOne(bean any) (int64, error) {
 	if session.isAutoClose {
 		defer session.Close()
 	}
@@ -593,10 +593,10 @@ func (session *Session) InsertOne(bean interface{}) (int64, error) {
 }
 
 // genInsertColumns generates insert needed columns
-func (session *Session) genInsertColumns(bean interface{}) ([]string, []interface{}, error) {
+func (session *Session) genInsertColumns(bean any) ([]string, []any, error) {
 	table := session.statement.RefTable
 	colNames := make([]string, 0, len(table.ColumnsSeq()))
-	args := make([]interface{}, 0, len(table.ColumnsSeq()))
+	args := make([]any, 0, len(table.ColumnsSeq()))
 
 	for _, col := range table.Columns() {
 		if col.MapType == core.ONLYFROMDB {
@@ -664,7 +664,7 @@ func (session *Session) genInsertColumns(bean interface{}) ([]string, []interfac
 			args = append(args, val)
 
 			var colName = col.Name
-			session.afterClosures = append(session.afterClosures, func(bean interface{}) {
+			session.afterClosures = append(session.afterClosures, func(bean any) {
 				col := table.GetColumn(colName)
 				setColumnTime(bean, col, t)
 			})
@@ -683,7 +683,7 @@ func (session *Session) genInsertColumns(bean interface{}) ([]string, []interfac
 	return colNames, args, nil
 }
 
-func (session *Session) insertMapInterface(m map[string]interface{}) (int64, error) {
+func (session *Session) insertMapInterface(m map[string]any) (int64, error) {
 	if len(m) == 0 {
 		return 0, ErrParamsType
 	}
@@ -702,7 +702,7 @@ func (session *Session) insertMapInterface(m map[string]interface{}) (int64, err
 	}
 	sort.Strings(columns)
 
-	var args = make([]interface{}, 0, len(m))
+	var args = make([]any, 0, len(m))
 	for _, colName := range columns {
 		args = append(args, m[colName])
 	}
@@ -730,7 +730,7 @@ func (session *Session) insertMapString(m map[string]string) (int64, error) {
 
 	sort.Strings(columns)
 
-	var args = make([]interface{}, 0, len(m))
+	var args = make([]any, 0, len(m))
 	for _, colName := range columns {
 		args = append(args, m[colName])
 	}
@@ -738,7 +738,7 @@ func (session *Session) insertMapString(m map[string]string) (int64, error) {
 	return session.insertMap(columns, args)
 }
 
-func (session *Session) insertMap(columns []string, args []interface{}) (int64, error) {
+func (session *Session) insertMap(columns []string, args []any) (int64, error) {
 	tableName := session.statement.TableName()
 	if len(tableName) <= 0 {
 		return 0, ErrTableNotFound
