@@ -1,20 +1,13 @@
-import { IMarkdownString } from 'monaco-editor';
+import { IMarkdownString, languages } from 'monaco-editor';
 
 import { SelectableValue } from '@grafana/data';
 import { isFetchError } from '@grafana/runtime';
 import type { Monaco, monacoTypes } from '@grafana/ui';
 
-import { createErrorNotification } from '../../../../core/copy/appNotification';
-import { notifyApp } from '../../../../core/reducers/appNotification';
-import { dispatch } from '../../../../store/store';
 import TempoLanguageProvider from '../language_provider';
 
 import { getSituation, Situation } from './situation';
-import { intrinsics, scopes } from './traceql';
-
-interface Props {
-  languageProvider: TempoLanguageProvider;
-}
+import { scopes } from './traceql';
 
 type MinimalCompletionItem = {
   label: string;
@@ -23,6 +16,17 @@ type MinimalCompletionItem = {
   documentation?: string | IMarkdownString;
 };
 
+export type CompletionItemType = 'TAG_NAME' | 'TAG_VALUE' | 'KEYWORD' | 'OPERATOR' | 'SCOPE' | 'FUNCTION';
+type CompletionItem = MinimalCompletionItem & {
+  type: CompletionItemType;
+  insertTextRules?: monacoTypes.languages.CompletionItemInsertTextRule; // we used it to position the cursor
+};
+
+interface Props {
+  languageProvider: TempoLanguageProvider;
+  setAlertText: (text?: string) => void;
+}
+
 /**
  * Class that implements CompletionItemProvider interface and allows us to provide suggestion for the Monaco
  * autocomplete system.
@@ -33,9 +37,11 @@ type MinimalCompletionItem = {
 export class CompletionProvider implements monacoTypes.languages.CompletionItemProvider {
   languageProvider: TempoLanguageProvider;
   registerInteractionCommandId: string | null;
+  setAlertText: (text?: string) => void;
 
   constructor(props: Props) {
     this.languageProvider = props.languageProvider;
+    this.setAlertText = props.setAlertText;
     this.registerInteractionCommandId = null;
   }
 
@@ -137,6 +143,20 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
       documentation:
         'Child operator. Looks for spans matching {condB} that are direct child spans of a parent matching {condA}',
     },
+    {
+      label: '<<',
+      insertText: '<<',
+      detail: 'Ancestor',
+      documentation:
+        'Ancestor operator. Looks for spans matching {condB} that are ancestors of a span matching {condA}',
+    },
+    {
+      label: '<',
+      insertText: '<',
+      detail: 'Parent',
+      documentation:
+        'Parent operator. Looks for spans matching {condB} that are direct parent spans of a child matching {condA}',
+    },
     {
       label: '~',
       insertText: '~',
@@ -157,19 +177,19 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
   ];
 
   // Functions (aggregator, selector, and combining operators)
-  static readonly spansetAggregatorOps: MinimalCompletionItem[] = [
-    {
-      label: 'count',
-      insertText: 'count()$0',
-      detail: 'Number of spans',
-      documentation: 'Counts the number of spans in a spanset',
-    },
+  static readonly aggregatorFunctions: MinimalCompletionItem[] = [
     {
       label: 'avg',
       insertText: 'avg($0)',
       detail: 'Average of attribute',
       documentation: 'Computes the average of a given numeric attribute or intrinsic for a spanset.',
     },
+    {
+      label: 'count',
+      insertText: 'count()$0',
+      detail: 'Number of spans',
+      documentation: 'Counts the number of spans in a spanset.',
+    },
     {
       label: 'max',
       insertText: 'max($0)',
@@ -191,13 +211,37 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
   ];
 
   static readonly functions: MinimalCompletionItem[] = [
-    ...this.spansetAggregatorOps,
+    ...this.aggregatorFunctions,
     {
       label: 'by',
       insertText: 'by($0)',
       detail: 'Grouping of attributes',
       documentation: 'Groups by arbitrary attributes.',
     },
+    {
+      label: 'count_over_time',
+      insertText: 'count_over_time()$0',
+      detail: 'Number of spans over time',
+      documentation: 'Counts the number of spans over time.',
+    },
+    {
+      label: 'histogram_over_time',
+      insertText: 'histogram_over_time($0)',
+      detail: 'Histogram of attribute over time',
+      documentation: 'Retrieves a histogram of an attributes values over time which are sorted into buckets.',
+    },
+    {
+      label: 'quantile_over_time',
+      insertText: 'quantile_over_time($0)',
+      detail: 'Quantile of attribute over time',
+      documentation: 'Retrieves one or more quantiles of an attributes numeric values over time.',
+    },
+    {
+      label: 'rate',
+      insertText: 'rate()$0',
+      detail: 'Rate of spans',
+      documentation: 'Counts the rate of spans per second.',
+    },
     {
       label: 'select',
       insertText: 'select($0)',
@@ -229,32 +273,16 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
 
     const { range, offset } = getRangeAndOffset(this.monaco, model, position);
     const situation = getSituation(model.getValue(), offset);
-    const completionItems = situation != null ? this.getCompletions(situation) : Promise.resolve([]);
+    const completionItems = situation != null ? this.getCompletions(situation, this.setAlertText) : Promise.resolve([]);
 
     return completionItems.then((items) => {
-      // monaco by-default alphabetically orders the items.
-      // to stop it, we use a number-as-string sortkey,
-      // so that monaco keeps the order we use
-      const maxIndexDigits = items.length.toString().length;
-      const suggestions: monacoTypes.languages.CompletionItem[] = items.map((item, index) => {
-        const suggestion: monacoTypes.languages.CompletionItem = {
-          kind: getMonacoCompletionItemKind(item.type, this.monaco!),
-          label: item.label,
-          insertText: item.insertText,
-          insertTextRules: item.insertTextRules,
-          detail: item.detail,
-          documentation: item.documentation,
-          sortText: index.toString().padStart(maxIndexDigits, '0'), // to force the order we have
-          range,
-          command: {
-            id: this.registerInteractionCommandId || 'noOp',
-            title: 'Report Interaction',
-            arguments: [item.label, item.type],
-          },
-        };
-        fixSuggestion(suggestion, item.type, model, offset);
-        return suggestion;
-      });
+      const suggestions = completionItemsToSuggestions(
+        items,
+        range,
+        this.registerInteractionCommandId ?? undefined,
+        model.getValue(),
+        offset
+      );
       return { suggestions };
     });
   }
@@ -268,12 +296,13 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
 
   private async getTagValues(tagName: string, query: string): Promise<Array<SelectableValue<string>>> {
     let tagValues: Array<SelectableValue<string>>;
+    const cacheKey = `${tagName}:${query}`;
 
-    if (this.cachedValues.hasOwnProperty(tagName)) {
-      tagValues = this.cachedValues[tagName];
+    if (this.cachedValues.hasOwnProperty(cacheKey)) {
+      tagValues = this.cachedValues[cacheKey];
     } else {
       tagValues = await this.languageProvider.getOptionsV2(tagName, query);
-      this.cachedValues[tagName] = tagValues;
+      this.cachedValues[cacheKey] = tagValues;
     }
     return tagValues;
   }
@@ -283,15 +312,15 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
    * @param situation
    * @private
    */
-  private async getCompletions(situation: Situation): Promise<Completion[]> {
+  private async getCompletions(situation: Situation, setAlertText: (text?: string) => void): Promise<CompletionItem[]> {
     switch (situation.type) {
       // This should only happen for cases that we do not support yet
       case 'UNKNOWN': {
         return [];
       }
       case 'EMPTY': {
-        return this.getScopesCompletions('{ ')
-          .concat(this.getIntrinsicsCompletions('{ '))
+        return this.getScopesCompletions('{ ', '$0 }')
+          .concat(this.getIntrinsicsCompletions('{ ', '$0 }'))
           .concat(this.getTagsCompletions('{ .'));
       }
       case 'SPANSET_EMPTY':
@@ -300,46 +329,30 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
         return this.getTagsCompletions();
       }
       case 'SPANSET_IN_THE_MIDDLE':
-        return [...CompletionProvider.comparisonOps, ...CompletionProvider.logicalOps].map((key) => ({
-          ...key,
-          type: 'OPERATOR',
-        }));
       case 'SPANSET_EXPRESSION_OPERATORS_WITH_MISSING_CLOSED_BRACE':
-        return [...CompletionProvider.comparisonOps, ...CompletionProvider.logicalOps].map((key) => ({
-          ...key,
-          type: 'OPERATOR',
-        }));
+        return this.getOperatorsCompletions([...CompletionProvider.comparisonOps, ...CompletionProvider.logicalOps]);
       case 'SPANSET_IN_NAME':
         return this.getScopesCompletions().concat(this.getIntrinsicsCompletions()).concat(this.getTagsCompletions());
       case 'SPANSET_IN_NAME_SCOPE':
         return this.getTagsCompletions(undefined, situation.scope);
       case 'SPANSET_EXPRESSION_OPERATORS':
-        return [
+        return this.getOperatorsCompletions([
           ...CompletionProvider.comparisonOps,
           ...CompletionProvider.logicalOps,
           ...CompletionProvider.arithmeticOps,
-        ].map((key) => ({
-          ...key,
-          type: 'OPERATOR',
-        }));
+        ]);
       case 'SPANFIELD_COMBINING_OPERATORS':
-        return [
+        return this.getOperatorsCompletions([
           ...CompletionProvider.logicalOps,
           ...CompletionProvider.arithmeticOps,
           ...CompletionProvider.comparisonOps,
-        ].map((key) => ({
-          ...key,
-          type: 'OPERATOR',
-        }));
+        ]);
       case 'SPANSET_COMBINING_OPERATORS':
-        return CompletionProvider.spansetOps.map((key) => ({
-          ...key,
-          type: 'OPERATOR',
-        }));
+        return this.getOperatorsCompletions(CompletionProvider.spansetOps);
       case 'SPANSET_PIPELINE_AFTER_OPERATOR':
         const functions = CompletionProvider.functions.map((key) => ({
           ...key,
-          insertTextRules: this.monaco?.languages.CompletionItemInsertTextRule?.InsertAsSnippet,
+          insertTextRules: languages.CompletionItemInsertTextRule.InsertAsSnippet,
           type: 'FUNCTION' as const,
         }));
         const tags = this.getScopesCompletions()
@@ -347,24 +360,20 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
           .concat(this.getTagsCompletions('.'));
         return [...functions, ...tags];
       case 'SPANSET_COMPARISON_OPERATORS':
-        return CompletionProvider.comparisonOps.map((key) => ({
-          ...key,
-          type: 'OPERATOR',
-        }));
+        return this.getOperatorsCompletions(CompletionProvider.comparisonOps);
       case 'SPANSET_IN_VALUE':
         let tagValues;
         try {
           tagValues = await this.getTagValues(situation.tagName, situation.query);
+          setAlertText(undefined);
         } catch (error) {
           if (isFetchError(error)) {
-            dispatch(notifyApp(createErrorNotification(error.data.error, new Error(error.data.message))));
+            setAlertText(error.data.error);
           } else if (error instanceof Error) {
-            dispatch(notifyApp(createErrorNotification('Error', error)));
+            setAlertText(`Error: ${error.message}`);
           }
         }
 
-        const items: Completion[] = [];
-
         const getInsertionText = (val: SelectableValue<string>): string => {
           if (situation.betweenQuotes) {
             return val.label!;
@@ -372,6 +381,7 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
           return val.type === 'string' ? `"${val.label}"` : val.label!;
         };
 
+        const items: CompletionItem[] = [];
         tagValues?.forEach((val) => {
           if (val?.label) {
             items.push({
@@ -399,32 +409,33 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
     }
   }
 
-  private getTagsCompletions(prepend?: string, scope?: string): Completion[] {
+  private getTagsCompletions(prepend?: string, scope?: string): CompletionItem[] {
     const tags = this.languageProvider.getTraceqlAutocompleteTags(scope);
-    return tags
-      .sort((a, b) => a.localeCompare(b, undefined, { sensitivity: 'accent' }))
-      .map((key) => ({
-        label: key,
-        insertText: (prepend || '') + key,
-        type: 'TAG_NAME',
-      }));
+    return tagsToCompletionItems(tags, prepend);
   }
 
-  private getIntrinsicsCompletions(prepend?: string, append?: string): Completion[] {
-    return intrinsics.map((key) => ({
+  private getIntrinsicsCompletions(prepend?: string, append?: string): CompletionItem[] {
+    return this.languageProvider.getIntrinsics().map((key) => ({
       label: key,
       insertText: (prepend || '') + key + (append || ''),
       type: 'KEYWORD',
-      insertTextRules: this.monaco?.languages.CompletionItemInsertTextRule?.InsertAsSnippet,
+      insertTextRules: languages.CompletionItemInsertTextRule?.InsertAsSnippet,
     }));
   }
 
-  private getScopesCompletions(prepend?: string, append?: string): Completion[] {
+  private getScopesCompletions(prepend?: string, append?: string): CompletionItem[] {
     return scopes.map((key) => ({
       label: key,
       insertText: (prepend || '') + key + (append || ''),
       type: 'SCOPE',
-      insertTextRules: this.monaco?.languages.CompletionItemInsertTextRule?.InsertAsSnippet,
+      insertTextRules: languages.CompletionItemInsertTextRule?.InsertAsSnippet,
+    }));
+  }
+
+  private getOperatorsCompletions(ops: MinimalCompletionItem[]): CompletionItem[] {
+    return ops.map((key) => ({
+      ...key,
+      type: 'OPERATOR',
     }));
   }
 }
@@ -434,40 +445,25 @@ export class CompletionProvider implements monacoTypes.languages.CompletionItemP
  * @param type
  * @param monaco
  */
-function getMonacoCompletionItemKind(type: CompletionType, monaco: Monaco): monacoTypes.languages.CompletionItemKind {
+function getMonacoCompletionItemKind(type: CompletionItemType): languages.CompletionItemKind {
   switch (type) {
     case 'TAG_NAME':
-      return monaco.languages.CompletionItemKind.Enum;
+      return languages.CompletionItemKind.Enum;
     case 'KEYWORD':
-      return monaco.languages.CompletionItemKind.Keyword;
+      return languages.CompletionItemKind.Keyword;
     case 'OPERATOR':
-      return monaco.languages.CompletionItemKind.Operator;
+      return languages.CompletionItemKind.Operator;
     case 'TAG_VALUE':
-      return monaco.languages.CompletionItemKind.EnumMember;
+      return languages.CompletionItemKind.EnumMember;
     case 'SCOPE':
-      return monaco.languages.CompletionItemKind.Class;
+      return languages.CompletionItemKind.Class;
     case 'FUNCTION':
-      return monaco.languages.CompletionItemKind.Function;
+      return languages.CompletionItemKind.Function;
     default:
-      throw new Error(`Unexpected CompletionType: ${type}`);
+      throw new Error(`Unexpected CompletionItemType: ${type}`);
   }
 }
 
-export type CompletionType = 'TAG_NAME' | 'TAG_VALUE' | 'KEYWORD' | 'OPERATOR' | 'SCOPE' | 'FUNCTION';
-type Completion = {
-  type: CompletionType;
-  label: string;
-  insertText: string;
-  insertTextRules?: monacoTypes.languages.CompletionItemInsertTextRule; // we used it to position the cursor
-  documentation?: string | IMarkdownString;
-  detail?: string;
-};
-
-export type Tag = {
-  name: string;
-  value: string;
-};
-
 function getRangeAndOffset(monaco: Monaco, model: monacoTypes.editor.ITextModel, position: monacoTypes.Position) {
   const word = model.getWordAtPosition(position);
   const range =
@@ -490,6 +486,47 @@ function getRangeAndOffset(monaco: Monaco, model: monacoTypes.editor.ITextModel,
   return { offset, range };
 }
 
+const SUGGEST_REGEXP = /(event\.|instrumentation\.|link\.|resource\.|span\.|\.)?([\w./-]*)$/;
+
+function completionItemsToSuggestions(
+  items: CompletionItem[],
+  range: monacoTypes.IRange | languages.CompletionItemRanges,
+  registerInteractionCommandId = 'noOp',
+  modelValue: string,
+  offset: number
+) {
+  // monaco by-default alphabetically orders the items.
+  // to stop it, we use a number-as-string sortkey,
+  // so that monaco keeps the order we use
+  const [_, scope, tag] = modelValue.substring(0, offset).match(SUGGEST_REGEXP) ?? [];
+  const maxIndexDigits = items.length.toString().length;
+  const suggestions: languages.CompletionItem[] = items.map((item, index) => {
+    const suggestion: languages.CompletionItem = {
+      kind: getMonacoCompletionItemKind(item.type),
+      label: item.label,
+      insertText: item.insertText,
+      insertTextRules: item.insertTextRules,
+      detail: item.detail,
+      documentation: item.documentation,
+      sortText: index.toString().padStart(maxIndexDigits, '0'), // to force the order we have
+      range,
+      command: {
+        id: registerInteractionCommandId,
+        title: 'Report Interaction',
+        arguments: [item.label, item.type],
+      },
+    };
+
+    if (tag && item.type === 'TAG_NAME') {
+      fixSuggestion(suggestion, offset, tag, scope);
+    }
+
+    return suggestion;
+  });
+
+  return suggestions;
+}
+
 /**
  * Fix the suggestions range and insert text. For the range we have to adjust because monaco by default replaces just
  * the last word which stops at dot while traceQL tags contain dots themselves and we want to replace the whole tag
@@ -497,34 +534,25 @@ function getRangeAndOffset(monaco: Monaco, model: monacoTypes.editor.ITextModel,
  * This may be doable also when creating the suggestions but for a particular situation this seems to be easier to do
  * here.
  */
-function fixSuggestion(
-  suggestion: monacoTypes.languages.CompletionItem,
-  itemType: CompletionType,
-  model: monacoTypes.editor.ITextModel,
-  offset: number
-) {
-  if (itemType === 'TAG_NAME') {
-    const match = model
-      .getValue()
-      .substring(0, offset)
-      .match(/(span\.|resource\.|\.)?([\w./-]*)$/);
-
-    if (match) {
-      const scope = match[1];
-      const tag = match[2];
-
-      if (tag) {
-        // Add the default scope if needed.
-        if (!scope && suggestion.insertText[0] !== '.') {
-          suggestion.insertText = '.' + suggestion.insertText;
-        }
-
-        // Adjust the range, so that we will replace the whole tag.
-        suggestion.range = {
-          ...suggestion.range,
-          startColumn: offset - tag.length + 1,
-        };
-      }
-    }
+function fixSuggestion(suggestion: monacoTypes.languages.CompletionItem, offset: number, tag: string, scope?: string) {
+  // Add the default scope if needed.
+  if (scope == null && suggestion.insertText[0] !== '.') {
+    suggestion.insertText = '.' + suggestion.insertText;
   }
+
+  // Adjust the range, so that we will replace the whole tag.
+  suggestion.range = {
+    ...suggestion.range,
+    startColumn: offset - tag.length + 1,
+  };
+}
+
+const collator = new Intl.Collator('en', { sensitivity: 'accent' });
+
+function tagsToCompletionItems(tags: string[], prepend = ''): CompletionItem[] {
+  return tags.sort(collator.compare).map((key) => ({
+    label: key,
+    insertText: `${prepend}${key}`,
+    type: 'TAG_NAME',
+  }));
 }
